"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6.QtXml import *


class QDomElement(QDomNode):
    """
    https://doc.qt.io/qt-6/qdomelement.html

    **Detailed Description**

    Elements have a **tagName** () and zero or more attributes associated with
    them. The tag name can be changed with **setTagName** ().

    Element attributes are represented by **QDomAttr**  objects that can be
    queried using the **attribute** () and **attributeNode** () functions. You
    can set attributes with the **setAttribute** () and **setAttributeNode** ()
    functions. Attributes can be removed with **removeAttribute** (). There are
    namespace-aware equivalents to these functions, i.e. **setAttributeNS** (),
    **setAttributeNodeNS** () and **removeAttributeNS** ().

    If you want to access the text of a node use **text** (), e.g.

    **QDomElement**  e = //...
        //...
        **QString**  s = e.text()

    The **text** () function operates recursively to find the text (since not
    all elements contain text). If you want to find all the text in all of a
    node's children, iterate over the children looking for **QDomText**  nodes,
    e.g.

    **QString**  text;
        **QDomElement**  element = doc.documentElement();
    for(**QDomNode**  n = element.firstChild(); !n.isNull(); n =
    n.nextSibling())
        {
            **QDomText**  t = n.toText();
            if
    (!t.isNull())
                text += t.data();
        }

    Note that we attempt to convert each node to a text node and use **text** ()
    rather than using **firstChild** ().**toText** ().data() or n.**toText**
    ().data() directly on the node, because the node may not be a text element.

    You can get a list of all the decendents of an element which have a
    specified tag name with **elementsByTagName** () or **elementsByTagNameNS**
    ().

    To browse the elements of a dom document use **firstChildElement** (),
    **lastChildElement** (), **nextSiblingElement** () and
    **previousSiblingElement** (). For example, to iterate over all child
    elements called "entry" in a root element called "database", you can use:

    **QDomDocument**  doc = // ...
        **QDomElement**  root =
    doc.firstChildElement("database");
        **QDomElement**  elt =
    root.firstChildElement("entry");
        for (; !elt.isNull(); elt =
    elt.nextSiblingElement("entry")) {
            // ...
        }

    For further information about the Document Object Model see **Level 1**  and
    **Level 2 Core** . For a more general introduction of the DOM implementation
    see the **QDomDocument**  documentation.
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#QDomElement

        **QDomElement::QDomElement()**

        Constructs an empty element. Use the **QDomDocument::createElement** ()
        function to construct elements with content.
        """
        ...

    @typing.overload
    def __init__(self, x: "QDomElement") -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#QDomElement-1

        **QDomElement::QDomElement(const QDomElement & x )**

        Constructs a copy of **x**.

        The data of the copy is shared (shallow copy): modifying one node will
        also change the other. If you want to make a deep copy, use
        **cloneNode** ().
        """
        ...

    def text(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomelement.html#text

        **QString QDomElement::text() const**

        Returns the element's text or an empty string.

        Example:

        <h1>Hello <b>Qt</b> <![CDATA[<xml is cool>]]></h1>

        The function text() of the **QDomElement**  for the `<h1>` tag, will
        return the following text:

        Hello Qt <xml is cool>

        Comments are ignored by this function. It only evaluates **QDomText**
        and **QDomCDATASection**  objects.
        """
        ...

    def nodeType(self) -> QDomNode.NodeType:
        """
        https://doc.qt.io/qt-6/qdomelement.html#nodeType

        **QDomNode::NodeType QDomElement::nodeType() const**

        Returns `ElementNode`.
        """
        ...

    def attributes(self) -> QDomNamedNodeMap:
        """
        https://doc.qt.io/qt-6/qdomelement.html#attributes

        **QDomNamedNodeMap QDomElement::attributes() const**

        Returns a **QDomNamedNodeMap**  containing all this element's
        attributes.

        **See also** **attribute** (), **setAttribute** (), **attributeNode**
        (), and **setAttributeNode** ().
        """
        ...

    def setTagName(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setTagName

        **void QDomElement::setTagName(const QString & name )**

        Sets this element's tag name to **name**.

        **See also** **tagName** ().
        """
        ...

    def tagName(self) -> str:
        """
        https://doc.qt.io/qt-6/qdomelement.html#tagName

        **QString QDomElement::tagName() const**

        Returns the tag name of this element. For an XML element like this:

        <img src="myimg.png">

        the tagname would return "img".

        **See also** **setTagName** ().
        """
        ...

    def hasAttributeNS(self, nsURI: str, localName: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdomelement.html#hasAttributeNS

        **bool QDomElement::hasAttributeNS(const QString & nsURI , const QString
        & localName ) const**

        Returns `true` if this element has an attribute with the local name
        **localName** and the namespace URI **nsURI** ; otherwise returns false.
        """
        ...

    def elementsByTagNameNS(self, nsURI: str, localName: str) -> QDomNodeList:
        """
        https://doc.qt.io/qt-6/qdomelement.html#elementsByTagNameNS

        **QDomNodeList QDomElement::elementsByTagNameNS(const QString & nsURI ,
        const QString & localName ) const**

        Returns a **QDomNodeList**  containing all descendants of this element
        with local name **localName** and namespace URI **nsURI** encountered
        during a preorder traversal of the element subtree with this element as
        its root. The order of the elements in the returned list is the order
        they are encountered during the preorder traversal.

        **See also** **elementsByTagName** () and
        **QDomDocument::elementsByTagNameNS** ().
        """
        ...

    def setAttributeNodeNS(self, newAttr: QDomAttr) -> QDomAttr:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttributeNodeNS

        **QDomAttr QDomElement::setAttributeNodeNS(const QDomAttr & newAttr )**

        Adds the attribute **newAttr** to this element.

        If the element has another attribute that has the same local name and
        namespace URI as **newAttr** , this function replaces that attribute and
        returns it; otherwise the function returns a **null attribute** .

        **See also** **attributeNodeNS** (), **setAttributeNS** (), and
        **setAttributeNode** ().
        """
        ...

    def attributeNodeNS(self, nsURI: str, localName: str) -> QDomAttr:
        """
        https://doc.qt.io/qt-6/qdomelement.html#attributeNodeNS

        **QDomAttr QDomElement::attributeNodeNS(const QString & nsURI , const
        QString & localName )**

        Returns the **QDomAttr**  object that corresponds to the attribute with
        the local name **localName** and the namespace URI **nsURI**. If no such
        attribute exists a **null attribute**  is returned.

        **See also** **setAttributeNodeNS** (), **setAttributeNode** (),
        **attribute** (), and **setAttribute** ().
        """
        ...

    def removeAttributeNS(self, nsURI: str, localName: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#removeAttributeNS

        **void QDomElement::removeAttributeNS(const QString & nsURI , const
        QString & localName )**

        Removes the attribute with the local name **localName** and the
        namespace URI **nsURI** from this element.

        **See also** **setAttributeNS** (), **attributeNS** (), and
        **removeAttribute** ().
        """
        ...

    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttributeNS

        **void QDomElement::setAttributeNS(const QString & nsURI , const QString
        & qName , const QString & value )**

        Adds an attribute with the qualified name **qName** and the namespace
        URI **nsURI** with the value **value**. If an attribute with the same
        local name and namespace URI exists, its prefix is replaced by the
        prefix of **qName** and its value is replaced by **value**.

        Although **qName** is the qualified name, the local name is used to
        decide if an existing attribute's value should be replaced.

        **See also** **attributeNS** (), **setAttributeNodeNS** (), and
        **setAttribute** ().
        """
        ...

    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttributeNS-1

        **void QDomElement::setAttributeNS(const QString & nsURI , const QString
        & qName , int value )**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def setAttributeNS(self, nsURI: str, qName: str, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttributeNS-2

        **void QDomElement::setAttributeNS(const QString & nsURI , const QString
        & qName , uint value )**

        This is an overloaded function.
        """
        ...

    def attributeNS(self, nsURI: str, localName: str, defaultValue: str = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdomelement.html#attributeNS

        **QString QDomElement::attributeNS(const QString & nsURI , const QString
        & localName , const QString & defValue = QString()) const**

        Returns the attribute with the local name **localName** and the
        namespace URI **nsURI**. If the attribute does not exist **defValue** is
        returned.

        **See also** **setAttributeNS** (), **attributeNodeNS** (),
        **setAttributeNodeNS** (), and **attribute** ().
        """
        ...

    def hasAttribute(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qdomelement.html#hasAttribute

        **bool QDomElement::hasAttribute(const QString & name ) const**

        Returns `true` if this element has an attribute called **name** ;
        otherwise returns `false`.

        **Note:** This function does not take the presence of namespaces into
        account. As a result, the specified name will be tested against fully-
        qualified attribute names that include any namespace prefixes that may
        be present.

        Use **hasAttributeNS** () to explicitly test for attributes with
        specific namespaces and names.
        """
        ...

    def elementsByTagName(self, tagname: str) -> QDomNodeList:
        """
        https://doc.qt.io/qt-6/qdomelement.html#elementsByTagName

        **QDomNodeList QDomElement::elementsByTagName(const QString & tagname )
        const**

        Returns a **QDomNodeList**  containing all descendants of this element
        named **tagname** encountered during a preorder traversal of the element
        subtree with this element as its root. The order of the elements in the
        returned list is the order they are encountered during the preorder
        traversal.

        **See also** **elementsByTagNameNS** () and
        **QDomDocument::elementsByTagName** ().
        """
        ...

    def removeAttributeNode(self, oldAttr: QDomAttr) -> QDomAttr:
        """
        https://doc.qt.io/qt-6/qdomelement.html#removeAttributeNode

        **QDomAttr QDomElement::removeAttributeNode(const QDomAttr & oldAttr )**

        Removes the attribute **oldAttr** from the element and returns it.

        **See also** **attributeNode** () and **setAttributeNode** ().
        """
        ...

    def setAttributeNode(self, newAttr: QDomAttr) -> QDomAttr:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttributeNode

        **QDomAttr QDomElement::setAttributeNode(const QDomAttr & newAttr )**

        Adds the attribute **newAttr** to this element.

        If the element has another attribute that has the same name as
        **newAttr** , this function replaces that attribute and returns it;
        otherwise the function returns a **null attribute** .

        **See also** **attributeNode** (), **setAttribute** (), and
        **setAttributeNodeNS** ().
        """
        ...

    def attributeNode(self, name: str) -> QDomAttr:
        """
        https://doc.qt.io/qt-6/qdomelement.html#attributeNode

        **QDomAttr QDomElement::attributeNode(const QString & name )**

        Returns the **QDomAttr**  object that corresponds to the attribute
        called **name**. If no such attribute exists a **null attribute**  is
        returned.

        **See also** **setAttributeNode** (), **attribute** (), **setAttribute**
        (), and **attributeNodeNS** ().
        """
        ...

    def removeAttribute(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#removeAttribute

        **void QDomElement::removeAttribute(const QString & name )**

        Removes the attribute called name **name** from this element.

        **See also** **setAttribute** (), **attribute** (), and
        **removeAttributeNS** ().
        """
        ...

    @typing.overload
    def setAttribute(self, name: str, value: str) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttribute

        **void QDomElement::setAttribute(const QString & name , const QString &
        value )**

        Adds an attribute called **name** with value **value**. If an attribute
        with the same name exists, its value is replaced by **value**.

        **See also** **attribute** (), **setAttributeNode** (), and
        **setAttributeNS** ().
        """
        ...

    @typing.overload
    def setAttribute(self, name: str, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttribute-1

        **void QDomElement::setAttribute(const QString & name , qlonglong value
        )**

        This is an overloaded function.

        The formatting always uses **QLocale::C** .
        """
        ...

    @typing.overload
    def setAttribute(self, name: str, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttribute-2

        **void QDomElement::setAttribute(const QString & name , qulonglong value
        )**

        This is an overloaded function.

        The formatting always uses **QLocale::C** .
        """
        ...

    @typing.overload
    def setAttribute(self, name: str, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttribute-3

        **void QDomElement::setAttribute(const QString & name , int value )**

        This is an overloaded function.

        The formatting always uses **QLocale::C** .
        """
        ...

    @typing.overload
    def setAttribute(self, name: str, value: int) -> None:
        """
        https://doc.qt.io/qt-6/qdomelement.html#setAttribute-4

        **void QDomElement::setAttribute(const QString & name , uint value )**

        This is an overloaded function.

        The formatting always uses **QLocale::C** .
        """
        ...

    def attribute(self, name: str, defaultValue: str = ...) -> str:
        """
        https://doc.qt.io/qt-6/qdomelement.html#attribute

        **QString QDomElement::attribute(const QString & name , const QString &
        defValue = QString()) const**

        Returns the attribute called **name**. If the attribute does not exist
        **defValue** is returned.

        **See also** **setAttribute** (), **attributeNode** (),
        **setAttributeNode** (), and **attributeNS** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QAbstractScrollArea(QFrame):
    """
    https://doc.qt.io/qt-6/qabstractscrollarea.html

    **Detailed Description**

    QAbstractScrollArea is a low-level abstraction of a scrolling area. The area
    provides a central widget called the viewport, in which the contents of the
    area is to be scrolled (i.e, the visible parts of the contents are rendered
    in the viewport).

    Next to the viewport is a vertical scroll bar, and below is a horizontal
    scroll bar. When all of the area contents fits in the viewport, each scroll
    bar can be either visible or hidden depending on the scroll bar's
    **Qt::ScrollBarPolicy** . When a scroll bar is hidden, the viewport expands
    in order to cover all available space. When a scroll bar becomes visible
    again, the viewport shrinks in order to make room for the scroll bar.

    It is possible to reserve a margin area around the viewport, see
    **setViewportMargins** (). The feature is mostly used to place a
    **QHeaderView**  widget above or beside the scrolling area. Subclasses of
    QAbstractScrollArea should implement margins.

    When inheriting QAbstractScrollArea, you need to do the following:

    * Control the scroll bars by setting their range, value, page step, and
    tracking their movements.
      * Draw the contents of the area in the viewport
    according to the values of the scroll bars.
      * Handle events received by
    the viewport in **viewportEvent** () - notably resize events.
      * Use
    `viewport->update()` to update the contents of the viewport instead of
    **update** () as all painting operations take place on the viewport.

    With a scroll bar policy of **Qt::ScrollBarAsNeeded**  (the default),
    QAbstractScrollArea shows scroll bars when they provide a non-zero scrolling
    range, and hides them otherwise.

    The scroll bars and viewport should be updated whenever the viewport
    receives a resize event or the size of the contents changes. The viewport
    also needs to be updated when the scroll bars values change. The initial
    values of the scroll bars are often set when the area receives new contents.

    We give a simple example, in which we have implemented a scroll area that
    can scroll any **QWidget** . We make the widget a child of the viewport;
    this way, we do not have to calculate which part of the widget to draw but
    can simply move the widget with **QWidget::move** (). When the area contents
    or the viewport size changes, we do the following:

    **QSize**  areaSize = viewport()->size();
            **QSize**   widgetSize =
    widget->size();
    verticalScrollBar()->setPageStep(areaSize.height());
    horizontalScrollBar()->setPageStep(areaSize.width());
    verticalScrollBar()->setRange(0, widgetSize.height() - areaSize.height());
    horizontalScrollBar()->setRange(0, widgetSize.width() - areaSize.width());
    updateWidgetPosition();

    When the scroll bars change value, we need to update the widget position,
    i.e., find the part of the widget that is to be drawn in the viewport:

    int hvalue = horizontalScrollBar()->value();
            int vvalue =
    verticalScrollBar()->value();
            **QPoint**  topLeft =
    viewport()->rect().topLeft();

            widget->move(topLeft.x() -
    hvalue, topLeft.y() - vvalue);

    In order to track scroll bar movements, reimplement the virtual function
    **scrollContentsBy** (). In order to fine-tune scrolling behavior, connect
    to a scroll bar's **QAbstractSlider::actionTriggered** () signal and adjust
    the **QAbstractSlider::sliderPosition**  as you wish.

    For convenience, QAbstractScrollArea makes all viewport events available in
    the virtual **viewportEvent** () handler. **QWidget** 's specialized
    handlers are remapped to viewport events in the cases where this makes
    sense. The remapped specialized handlers are: **paintEvent** (),
    **mousePressEvent** (), **mouseReleaseEvent** (), **mouseDoubleClickEvent**
    (), **mouseMoveEvent** (), **wheelEvent** (), **dragEnterEvent** (),
    **dragMoveEvent** (), **dragLeaveEvent** (), **dropEvent** (),
    **contextMenuEvent** (), and **resizeEvent** ().

    **QScrollArea** , which inherits QAbstractScrollArea, provides smooth
    scrolling for any **QWidget**  (i.e., the widget is scrolled pixel by
    pixel). You only need to subclass QAbstractScrollArea if you need more
    specialized behavior. This is, for instance, true if the entire contents of
    the area is not suitable for being drawn on a **QWidget**  or if you do not
    want smooth scrolling.

    **See also** **QScrollArea** .
    """

    class SizeAdjustPolicy(enum.Enum):
        AdjustIgnored: QAbstractScrollArea = ...
        AdjustToContentsOnFirstShow: QAbstractScrollArea = ...
        AdjustToContents: QAbstractScrollArea = ...

    def __init__(self, parent: typing.Optional[QWidget] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#QAbstractScrollArea

        **QAbstractScrollArea::QAbstractScrollArea(QWidget * parent = nullptr)**

        Constructs a viewport.

        The **parent** argument is sent to the **QWidget**  constructor.
        """
        ...

    def setSizeAdjustPolicy(
        self, policy: "QAbstractScrollArea.SizeAdjustPolicy"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#sizeAdjustPolicy-prop

        **[since 5.2] sizeAdjustPolicy : SizeAdjustPolicy**

        This property holds the policy describing how the size of the scroll
        area changes when the size of the viewport changes.

        The default policy is **QAbstractScrollArea::AdjustIgnored** . Changing
        this property might actually resize the scrollarea.

        This property was introduced in Qt 5.2.

        **Access functions:**

        QAbstractScrollArea::SizeAdjustPolicy **sizeAdjustPolicy** () const
        void **setSizeAdjustPolicy** (QAbstractScrollArea::SizeAdjustPolicy
        **policy** )
        """
        ...

    def sizeAdjustPolicy(self) -> "QAbstractScrollArea.SizeAdjustPolicy":
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#sizeAdjustPolicy-prop

        **[since 5.2] sizeAdjustPolicy : SizeAdjustPolicy**

        This property holds the policy describing how the size of the scroll
        area changes when the size of the viewport changes.

        The default policy is **QAbstractScrollArea::AdjustIgnored** . Changing
        this property might actually resize the scrollarea.

        This property was introduced in Qt 5.2.

        **Access functions:**

        QAbstractScrollArea::SizeAdjustPolicy **sizeAdjustPolicy** () const
        void **setSizeAdjustPolicy** (QAbstractScrollArea::SizeAdjustPolicy
        **policy** )
        """
        ...

    def setupViewport(self, viewport: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setupViewport

        **[virtual] void QAbstractScrollArea::setupViewport(QWidget * viewport
        )**

        This slot is called by **QAbstractScrollArea**  after **setViewport** (
        **viewport** ) has been called. Reimplement this function in a subclass
        of **QAbstractScrollArea**  to initialize the new **viewport** before it
        is used.

        **See also** **setViewport** ().
        """
        ...

    def setViewport(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setViewport

        **void QAbstractScrollArea::setViewport(QWidget * widget )**

        Sets the viewport to be the given **widget**. The
        **QAbstractScrollArea**  will take ownership of the given **widget**.

        If **widget** is `nullptr`, **QAbstractScrollArea**  will assign a new
        **QWidget**  instance for the viewport.

        **See also** **viewport** ().
        """
        ...

    def scrollBarWidgets(
        self, alignment: QtCore.Qt.AlignmentFlag
    ) -> typing.List[QWidget]:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#scrollBarWidgets

        **QWidgetList QAbstractScrollArea::scrollBarWidgets(Qt::Alignment
        alignment )**

        Returns a list of the currently set scroll bar widgets. **alignment**
        can be any combination of the four location flags.

        **See also** **addScrollBarWidget** ().
        """
        ...

    def addScrollBarWidget(
        self, widget: QWidget, alignment: QtCore.Qt.AlignmentFlag
    ) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#addScrollBarWidget

        **void QAbstractScrollArea::addScrollBarWidget(QWidget * widget ,
        Qt::Alignment alignment )**

        Adds **widget** as a scroll bar widget in the location specified by
        **alignment**.

        Scroll bar widgets are shown next to the horizontal or vertical scroll
        bar, and can be placed on either side of it. If you want the scroll bar
        widgets to be always visible, set the scrollBarPolicy for the
        corresponding scroll bar to `AlwaysOn`.

        **alignment** must be one of Qt::Alignleft and **Qt::AlignRight** ,
        which maps to the horizontal scroll bar, or **Qt::AlignTop**  and
        **Qt::AlignBottom** , which maps to the vertical scroll bar.

        A scroll bar widget can be removed by either re-parenting the widget or
        deleting it. It's also possible to hide a widget with **QWidget::hide**
        ()

        The scroll bar widget will be resized to fit the scroll bar geometry for
        the current style. The following describes the case for scroll bar
        widgets on the horizontal scroll bar:

        The height of the widget will be set to match the height of the scroll
        bar. To control the width of the widget, use
        **QWidget::setMinimumWidth**  and **QWidget::setMaximumWidth** , or
        implement **QWidget::sizeHint** () and set a horizontal size policy. If
        you want a square widget, call **QStyle::pixelMetric**
        (**QStyle::PM_ScrollBarExtent** ) and set the width to this value.

        **See also** **scrollBarWidgets** ().
        """
        ...

    def setCornerWidget(self, widget: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setCornerWidget

        **void QAbstractScrollArea::setCornerWidget(QWidget * widget )**

        Sets the widget in the corner between the two scroll bars to be
        **widget**.

        You will probably also want to set at least one of the scroll bar modes
        to `AlwaysOn`.

        Passing `nullptr` shows no widget in the corner.

        Any previous corner widget is hidden.

        You may call setCornerWidget() with the same widget at different times.

        All widgets set here will be deleted by the scroll area when it is
        destroyed unless you separately reparent the widget after setting some
        other corner widget (or `nullptr`).

        Any **newly** set widget should have no current parent.

        By default, no corner widget is present.

        **See also** **cornerWidget** (), **horizontalScrollBarPolicy** , and
        **horizontalScrollBarPolicy** .
        """
        ...

    def cornerWidget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#cornerWidget

        **QWidget *QAbstractScrollArea::cornerWidget() const**

        Returns the widget in the corner between the two scroll bars.

        By default, no corner widget is present.

        **See also** **setCornerWidget** ().
        """
        ...

    def setHorizontalScrollBar(self, scrollbar: "QScrollBar") -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setHorizontalScrollBar

        **void QAbstractScrollArea::setHorizontalScrollBar(QScrollBar *
        scrollBar )**

        Replaces the existing horizontal scroll bar with **scrollBar** , and
        sets all the former scroll bar's slider properties on the new scroll
        bar. The former scroll bar is then deleted.

        **QAbstractScrollArea**  already provides horizontal and vertical scroll
        bars by default. You can call this function to replace the default
        horizontal scroll bar with your own custom scroll bar.

        **See also** **horizontalScrollBar** () and **setVerticalScrollBar** ().
        """
        ...

    def setVerticalScrollBar(self, scrollbar: "QScrollBar") -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setVerticalScrollBar

        **void QAbstractScrollArea::setVerticalScrollBar(QScrollBar * scrollBar
        )**

        Replaces the existing vertical scroll bar with **scrollBar** , and sets
        all the former scroll bar's slider properties on the new scroll bar. The
        former scroll bar is then deleted.

        **QAbstractScrollArea**  already provides vertical and horizontal scroll
        bars by default. You can call this function to replace the default
        vertical scroll bar with your own custom scroll bar.

        **See also** **verticalScrollBar** () and **setHorizontalScrollBar** ().
        """
        ...

    def scrollContentsBy(self, dx: int, dy: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#scrollContentsBy

        **[virtual protected] void QAbstractScrollArea::scrollContentsBy(int dx
        , int dy )**

        This virtual handler is called when the scroll bars are moved by **dx**
        , **dy** , and consequently the viewport's contents should be scrolled
        accordingly.

        The default implementation simply calls **update** () on the entire
        **viewport** (), subclasses can reimplement this handler for
        optimization purposes, or - like **QScrollArea**  \\- to move a contents
        widget. The parameters **dx** and **dy** are there for convenience, so
        that the class knows how much should be scrolled (useful e.g. when doing
        pixel-shifts). You may just as well ignore these values and scroll
        directly to the position the scroll bars indicate.

        Calling this function in order to scroll programmatically is an error,
        use the scroll bars instead (e.g. by calling **QScrollBar::setValue** ()
        directly).
        """
        ...

    def eventFilter(self, a0: QtCore.QObject, a1: QtCore.QEvent) -> bool:
        ...

    def keyPressEvent(self, a0: QtGui.QKeyEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#keyPressEvent

        **[override virtual protected] void
        QAbstractScrollArea::keyPressEvent(QKeyEvent * e )**

        Reimplements: **QWidget::keyPressEvent** (QKeyEvent *event).

        This function is called with key event **e** when key presses occur. It
        handles PageUp, PageDown, Up, Down, Left, and Right, and ignores all
        other key presses.
        """
        ...

    def dropEvent(self, a0: QtGui.QDropEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#dropEvent

        **[override virtual protected] void
        QAbstractScrollArea::dropEvent(QDropEvent * event )**

        Reimplements: **QWidget::dropEvent** (QDropEvent *event).

        This event handler can be reimplemented in a subclass to receive drop
        events (passed in **event** ), for the **viewport** () widget.

        **See also** **QWidget::dropEvent** ().
        """
        ...

    def dragLeaveEvent(self, a0: QtGui.QDragLeaveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#dragLeaveEvent

        **[override virtual protected] void
        QAbstractScrollArea::dragLeaveEvent(QDragLeaveEvent * event )**

        Reimplements: **QWidget::dragLeaveEvent** (QDragLeaveEvent *event).

        This event handler can be reimplemented in a subclass to receive drag
        leave events (passed in **event** ), for the **viewport** () widget.

        **See also** **QWidget::dragLeaveEvent** ().
        """
        ...

    def dragMoveEvent(self, a0: QtGui.QDragMoveEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#dragMoveEvent

        **[override virtual protected] void
        QAbstractScrollArea::dragMoveEvent(QDragMoveEvent * event )**

        Reimplements: **QWidget::dragMoveEvent** (QDragMoveEvent *event).

        This event handler can be reimplemented in a subclass to receive drag
        move events (passed in **event** ), for the **viewport** () widget.

        **See also** **QWidget::dragMoveEvent** ().
        """
        ...

    def dragEnterEvent(self, a0: QtGui.QDragEnterEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#dragEnterEvent

        **[override virtual protected] void
        QAbstractScrollArea::dragEnterEvent(QDragEnterEvent * event )**

        Reimplements: **QWidget::dragEnterEvent** (QDragEnterEvent *event).

        This event handler can be reimplemented in a subclass to receive drag
        enter events (passed in **event** ), for the **viewport** () widget.

        **See also** **QWidget::dragEnterEvent** ().
        """
        ...

    def contextMenuEvent(self, a0: QtGui.QContextMenuEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#contextMenuEvent

        **[override virtual protected] void
        QAbstractScrollArea::contextMenuEvent(QContextMenuEvent * e )**

        Reimplements: **QWidget::contextMenuEvent** (QContextMenuEvent *event).

        This event handler can be reimplemented in a subclass to receive context
        menu events for the **viewport** () widget. The event is passed in
        **e**.

        **See also** **QWidget::contextMenuEvent** ().
        """
        ...

    def wheelEvent(self, a0: QtGui.QWheelEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#wheelEvent

        **[override virtual protected] void
        QAbstractScrollArea::wheelEvent(QWheelEvent * e )**

        Reimplements: **QWidget::wheelEvent** (QWheelEvent *event).

        This event handler can be reimplemented in a subclass to receive wheel
        events for the **viewport** () widget. The event is passed in **e**.

        **See also** **QWidget::wheelEvent** ().
        """
        ...

    def mouseMoveEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#mouseMoveEvent

        **[override virtual protected] void
        QAbstractScrollArea::mouseMoveEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseMoveEvent** (QMouseEvent *event).

        This event handler can be reimplemented in a subclass to receive mouse
        move events for the **viewport** () widget. The event is passed in
        **e**.

        **See also** **QWidget::mouseMoveEvent** ().
        """
        ...

    def mouseDoubleClickEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#mouseDoubleClickEvent

        **[override virtual protected] void
        QAbstractScrollArea::mouseDoubleClickEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseDoubleClickEvent** (QMouseEvent *event).

        This event handler can be reimplemented in a subclass to receive mouse
        double click events for the **viewport** () widget. The event is passed
        in **e**.

        **See also** **QWidget::mouseDoubleClickEvent** ().
        """
        ...

    def mouseReleaseEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#mouseReleaseEvent

        **[override virtual protected] void
        QAbstractScrollArea::mouseReleaseEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mouseReleaseEvent** (QMouseEvent *event).

        This event handler can be reimplemented in a subclass to receive mouse
        release events for the **viewport** () widget. The event is passed in
        **e**.

        **See also** **QWidget::mouseReleaseEvent** ().
        """
        ...

    def mousePressEvent(self, a0: QtGui.QMouseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#mousePressEvent

        **[override virtual protected] void
        QAbstractScrollArea::mousePressEvent(QMouseEvent * e )**

        Reimplements: **QWidget::mousePressEvent** (QMouseEvent *event).

        This event handler can be reimplemented in a subclass to receive mouse
        press events for the **viewport** () widget. The event is passed in
        **e**.

        The default implementation calls **QWidget::mousePressEvent** () for
        default popup handling.

        **See also** **QWidget::mousePressEvent** ().
        """
        ...

    def paintEvent(self, a0: QtGui.QPaintEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#paintEvent

        **[override virtual protected] void
        QAbstractScrollArea::paintEvent(QPaintEvent * event )**

        Reimplements: **QFrame::paintEvent** (QPaintEvent *).

        This event handler can be reimplemented in a subclass to receive paint
        events (passed in **event** ), for the **viewport** () widget.

        **Note:** If you open a painter, make sure to open it on the
        **viewport** ().

        **See also** **QWidget::paintEvent** ().
        """
        ...

    def resizeEvent(self, a0: QtGui.QResizeEvent) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#resizeEvent

        **[override virtual protected] void
        QAbstractScrollArea::resizeEvent(QResizeEvent * event )**

        Reimplements: **QWidget::resizeEvent** (QResizeEvent *event).

        This event handler can be reimplemented in a subclass to receive resize
        events (passed in **event** ), for the **viewport** () widget.

        When resizeEvent() is called, the viewport already has its new geometry:
        Its new size is accessible through the **QResizeEvent::size** ()
        function, and the old size through **QResizeEvent::oldSize** ().

        **See also** **QWidget::resizeEvent** ().
        """
        ...

    def viewportEvent(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#viewportEvent

        **[virtual protected] bool QAbstractScrollArea::viewportEvent(QEvent *
        event )**

        The main event handler for the scrolling area (the **viewport** ()
        widget). It handles the **event** specified, and can be called by
        subclasses to provide reasonable default behavior.

        Returns `true` to indicate to the event system that the event has been
        handled, and needs no further processing; otherwise returns `false` to
        indicate that the event should be propagated further.

        You can reimplement this function in a subclass, but we recommend using
        one of the specialized event handlers instead.

        Specialized handlers for viewport events are: **paintEvent** (),
        **mousePressEvent** (), **mouseReleaseEvent** (),
        **mouseDoubleClickEvent** (), **mouseMoveEvent** (), **wheelEvent** (),
        **dragEnterEvent** (), **dragMoveEvent** (), **dragLeaveEvent** (),
        **dropEvent** (), **contextMenuEvent** (), and **resizeEvent** ().
        """
        ...

    def event(self, a0: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#event

        **[override virtual protected] bool QAbstractScrollArea::event(QEvent *
        event )**

        Reimplements: **QFrame::event** (QEvent *e).

        This is the main event handler for the **QAbstractScrollArea**  widget (
        **not** the scrolling area **viewport** ()). The specified **event** is
        a general event object that may need to be cast to the appropriate class
        depending on its type.

        **See also** **QEvent::type** ().
        """
        ...

    def viewportSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#viewportSizeHint

        **[virtual protected, since 5.2] QSize
        QAbstractScrollArea::viewportSizeHint() const**

        Returns the recommended size for the viewport. The default
        implementation returns **viewport** ()->**sizeHint** (). Note that the
        size is just the viewport's size, without any scroll bars visible.

        This function was introduced in Qt 5.2.
        """
        ...

    def viewportMargins(self) -> QtCore.QMargins:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#viewportMargins

        **[protected, since 5.5] QMargins QAbstractScrollArea::viewportMargins()
        const**

        Returns the margins around the scrolling area. By default all the
        margins are zero.

        This function was introduced in Qt 5.5.

        **See also** **setViewportMargins** ().
        """
        ...

    @typing.overload
    def setViewportMargins(self, left: int, top: int, right: int, bottom: int) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setViewportMargins

        **[protected] void QAbstractScrollArea::setViewportMargins(int left ,
        int top , int right , int bottom )**

        Sets the margins around the scrolling area to **left** , **top** ,
        **right** and **bottom**. This is useful for applications such as
        spreadsheets with "locked" rows and columns. The marginal space is left
        blank; put widgets in the unused area.

        Note that this function is frequently called by **QTreeView**  and
        **QTableView** , so margins must be implemented by
        **QAbstractScrollArea**  subclasses. Also, if the subclasses are to be
        used in item views, they should not call this function.

        By default all margins are zero.

        **See also** **viewportMargins** ().
        """
        ...

    @typing.overload
    def setViewportMargins(self, margins: QtCore.QMargins) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#setViewportMargins-1

        **[protected] void QAbstractScrollArea::setViewportMargins(const
        QMargins & margins )**

        Sets **margins** around the scrolling area. This is useful for
        applications such as spreadsheets with "locked" rows and columns. The
        marginal space is is left blank; put widgets in the unused area.

        By default all margins are zero.

        **See also** **viewportMargins** ().
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#sizeHint

        **[override virtual] QSize QAbstractScrollArea::sizeHint() const**

        Reimplements: **QFrame::sizeHint() const** .

        Returns the sizeHint property of the scroll area. The size is determined
        by using **viewportSizeHint** () plus some extra space for scroll bars,
        if needed.
        """
        ...

    def minimumSizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#minimumSizeHint

        **[override virtual] QSize QAbstractScrollArea::minimumSizeHint()
        const**

        Reimplements an access function for property:
        **QWidget::minimumSizeHint** .
        """
        ...

    def maximumViewportSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#maximumViewportSize

        **QSize QAbstractScrollArea::maximumViewportSize() const**

        Returns the size of the viewport as if the scroll bars had no valid
        scrolling range.
        """
        ...

    def viewport(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#viewport

        **QWidget *QAbstractScrollArea::viewport() const**

        Returns the viewport widget.

        Use the **QScrollArea::widget** () function to retrieve the contents of
        the viewport widget.

        **See also** **setViewport** () and **QScrollArea::widget** ().
        """
        ...

    def horizontalScrollBar(self) -> "QScrollBar":
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#horizontalScrollBar

        **QScrollBar *QAbstractScrollArea::horizontalScrollBar() const**

        Returns the horizontal scroll bar.

        **See also** **setHorizontalScrollBar** (),
        **horizontalScrollBarPolicy** , and **verticalScrollBar** ().
        """
        ...

    def setHorizontalScrollBarPolicy(self, a0: QtCore.Qt.ScrollBarPolicy) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#horizontalScrollBarPolic
        y-prop

        **horizontalScrollBarPolicy : Qt::ScrollBarPolicy**

        This property holds the policy for the horizontal scroll bar

        The default policy is **Qt::ScrollBarAsNeeded** .

        **Access functions:**

        Qt::ScrollBarPolicy **horizontalScrollBarPolicy** () const
        void
        **setHorizontalScrollBarPolicy** (Qt::ScrollBarPolicy)

        **See also** **verticalScrollBarPolicy** .
        """
        ...

    def horizontalScrollBarPolicy(self) -> QtCore.Qt.ScrollBarPolicy:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#horizontalScrollBarPolic
        y-prop

        **horizontalScrollBarPolicy : Qt::ScrollBarPolicy**

        This property holds the policy for the horizontal scroll bar

        The default policy is **Qt::ScrollBarAsNeeded** .

        **Access functions:**

        Qt::ScrollBarPolicy **horizontalScrollBarPolicy** () const
        void
        **setHorizontalScrollBarPolicy** (Qt::ScrollBarPolicy)

        **See also** **verticalScrollBarPolicy** .
        """
        ...

    def verticalScrollBar(self) -> "QScrollBar":
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#verticalScrollBar

        **QScrollBar *QAbstractScrollArea::verticalScrollBar() const**

        Returns the vertical scroll bar.

        **See also** **setVerticalScrollBar** (), **verticalScrollBarPolicy** ,
        and **horizontalScrollBar** ().
        """
        ...

    def setVerticalScrollBarPolicy(self, a0: QtCore.Qt.ScrollBarPolicy) -> None:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#verticalScrollBarPolicy-
        prop

        **verticalScrollBarPolicy : Qt::ScrollBarPolicy**

        This property holds the policy for the vertical scroll bar

        The default policy is **Qt::ScrollBarAsNeeded** .

        **Access functions:**

        Qt::ScrollBarPolicy **verticalScrollBarPolicy** () const
        void
        **setVerticalScrollBarPolicy** (Qt::ScrollBarPolicy)

        **See also** **horizontalScrollBarPolicy** .

        **Member Function Documentation**
        """
        ...

    def verticalScrollBarPolicy(self) -> QtCore.Qt.ScrollBarPolicy:
        """
        https://doc.qt.io/qt-6/qabstractscrollarea.html#verticalScrollBarPolicy-
        prop

        **verticalScrollBarPolicy : Qt::ScrollBarPolicy**

        This property holds the policy for the vertical scroll bar

        The default policy is **Qt::ScrollBarAsNeeded** .

        **Access functions:**

        Qt::ScrollBarPolicy **verticalScrollBarPolicy** () const
        void
        **setVerticalScrollBarPolicy** (Qt::ScrollBarPolicy)

        **See also** **horizontalScrollBarPolicy** .

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtQml import *
import enum


class QJSValue(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qjsvalue.html

    **Detailed Description**

    QJSValue supports the types defined in the **ECMA-262**  standard: The
    primitive types, which are Undefined, Null, Boolean, Number, and String; and
    the Object and Array types. Additionally, built-in support is provided for
    Qt/C++ types such as **QVariant**  and **QObject** .

    For the object-based types (including Date and RegExp), use the newT()
    functions in **QJSEngine**  (e.g. **QJSEngine::newObject** ()) to create a
    QJSValue of the desired type. For the primitive types, use one of the
    QJSValue constructor overloads. For other types, e.g. registered gadget
    types such as **QPoint** , you can use **QJSEngine::toScriptValue** .

    The methods named isT() (e.g. **isBool** (), **isUndefined** ()) can be used
    to test if a value is of a certain type. The methods named toT() (e.g.
    **toBool** (), **toString** ()) can be used to convert a QJSValue to another
    type. You can also use the generic qjsvalue_cast() function.

    Object values have zero or more properties which are themselves QJSValues.
    Use **setProperty** () to set a property of an object, and call **property**
    () to retrieve the value of a property.

    **QJSEngine**  myEngine;
        **QJSValue**  myObject = myEngine.newObject();
    **QJSValue**  myOtherObject = myEngine.newObject();
    myObject.setProperty("myChild", myOtherObject);
    myObject.setProperty("name", "John Doe");

    If you want to iterate over the properties of a script object, use the
    **QJSValueIterator**  class.

    Object values have an internal `prototype` property, which can be accessed
    with **prototype** () and **setPrototype** ().

    Function objects (objects for which **isCallable** ()) returns true) can be
    invoked by calling **call** (). Constructor functions can be used to
    construct new objects by calling **callAsConstructor** ().

    Use **equals** () or **strictlyEquals** () to compare a QJSValue to another.

    Note that a QJSValue for which **isObject** () is true only carries a
    reference to an actual object; copying the QJSValue will only copy the
    object reference, not the object itself. If you want to clone an object
    (i.e. copy an object's properties to another object), you can do so with the
    help of a `for-in` statement in script code, or **QJSValueIterator**  in
    C++.

    **Working With Arrays**

    To create an array using QJSValue, use **QJSEngine::newArray** ():

    // Assumes that this class was declared in QML.
        **QJSValue**  jsArray =
    engine->newArray(3);

    To set individual elements in the array, use the **setProperty** (quint32
    arrayIndex, const QJSValue &value) overload. For example, to fill the array
    above with integers:

    for (int i = 0; i < 3; ++i) {
            jsArray.setProperty(i,
    **QRandomGenerator** ::global().generate());
        }

    To determine the length of the array, access the `"length"` property. To
    access array elements, use the **property** (quint32 arrayIndex) overload.
    The following code reads the array we created above back into a list:

    **QVector** <int> integers;
        const int length =
    jsArray.property("length").toInt();
        for (int i = 0; i < length; ++i) {
    integers.append(jsArray.property(i).toInt());
        }

    **See also** **QJSEngine**  and **QJSValueIterator** .
    """

    class ErrorType(enum.Enum):
        GenericError: QJSValue = ...
        EvalError: QJSValue = ...
        RangeError: QJSValue = ...
        ReferenceError: QJSValue = ...
        SyntaxError: QJSValue = ...
        TypeError: QJSValue = ...
        URIError: QJSValue = ...

    class ObjectConversionBehavior(enum.Enum):
        ConvertJSObjects: QJSValue = ...
        RetainJSObjects: QJSValue = ...

    class SpecialValue(enum.Enum):
        NullValue: QJSValue = ...
        UndefinedValue: QJSValue = ...

    @typing.overload
    def __init__(self, value: "QJSValue.SpecialValue" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#QJSValue

        **QJSValue::QJSValue(QJSValue::SpecialValue value = UndefinedValue)**

        Constructs a new QJSValue with a special **value**.
        """
        ...

    @typing.overload
    def __init__(
        self,
        other: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#QJSValue-1

        **QJSValue::QJSValue(const QJSValue & other )**

        Constructs a new QJSValue that is a copy of **other**.

        Note that if **other** is an object (i.e., **isObject** () would return
        true), then only a reference to the underlying object is copied into the
        new script value (i.e., the object itself is not copied).
        """
        ...

    def errorType(self) -> "QJSValue.ErrorType":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#errorType

        **[since 5.12] QJSValue::ErrorType QJSValue::errorType() const**

        Returns the error type this **QJSValue**  represents if it is an Error
        object. Otherwise, returns `NoError."`

        This function was introduced in Qt 5.12.

        **See also** **isError** () and **QJSEngine - Script Exceptions** .
        """
        ...

    def callAsConstructor(
        self,
        args: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#callAsConstructor

        **QJSValue QJSValue::callAsConstructor(const QJSValueList & args =
        QJSValueList()) const**

        Creates a new `Object` and calls this **QJSValue**  as a constructor,
        using the created object as the `this' object and passing **args** as
        arguments. If the return value from the constructor call is an object,
        then that object is returned; otherwise the default constructed object
        is returned.

        If this **QJSValue**  is not a function, callAsConstructor() does
        nothing and returns an undefined **QJSValue** .

        Calling this function can cause an exception to occur in the script
        engine; in that case, the value that was thrown (typically an `Error`
        object) is returned. You can call **isError** () on the return value to
        determine whether an exception occurred.

        **See also** **call** () and **QJSEngine::newObject** ().
        """
        ...

    def callWithInstance(
        self,
        instance: typing.Union[
            "QJSValue", "QJSValue.SpecialValue", bool, int, float, str
        ],
        args: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#callWithInstance

        **QJSValue QJSValue::callWithInstance(const QJSValue & instance , const
        QJSValueList & args = QJSValueList()) const**

        Calls this **QJSValue**  as a function, using **instance** as the `this'
        object in the function call, and passing **args** as arguments to the
        function. Returns the value returned from the function.

        If this **QJSValue**  is not a function, **call** () does nothing and
        returns an undefined **QJSValue** .

        Note that if **instance** is not an object, the global object (see
        **QJSEngine::globalObject** ()) will be used as the `this' object.

        Calling **call** () can cause an exception to occur in the script
        engine; in that case, **call** () returns the value that was thrown
        (typically an `Error` object). You can call **isError** () on the return
        value to determine whether an exception occurred.

        **See also** **call** ().
        """
        ...

    def call(
        self,
        args: typing.Iterable[
            typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str]
        ] = ...,
    ) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#call

        **QJSValue QJSValue::call(const QJSValueList & args = QJSValueList())
        const**

        Calls this **QJSValue**  as a function, passing **args** as arguments to
        the function, and using the globalObject() as the "this"-object. Returns
        the value returned from the function.

        If this **QJSValue**  is not callable, call() does nothing and returns
        an undefined **QJSValue** .

        Calling call() can cause an exception to occur in the script engine; in
        that case, call() returns the value that was thrown (typically an
        `Error` object). You can call **isError** () on the return value to
        determine whether an exception occurred.

        **See also** **isCallable** (), **callWithInstance** (), and
        **callAsConstructor** ().
        """
        ...

    def isCallable(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isCallable

        **bool QJSValue::isCallable() const**

        Returns true if this **QJSValue**  is a function, otherwise returns
        false.

        **See also** **call** ().
        """
        ...

    def deleteProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#deleteProperty

        **bool QJSValue::deleteProperty(const QString & name )**

        Attempts to delete this object's property of the given **name**. Returns
        true if the property was deleted, otherwise returns false.

        The behavior of this function is consistent with the JavaScript delete
        operator. In particular:

        * Non-configurable properties cannot be deleted.
          * This function will
        return true even if this object doesn't have a property of the given
        **name** (i.e., non-existent properties are "trivially deletable").
          *
        If this object doesn't have an own property of the given **name** , but
        an object in the **prototype** () chain does, the prototype object's
        property is not deleted, and this function returns true.

        **See also** **setProperty** () and **hasOwnProperty** ().
        """
        ...

    def hasOwnProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#hasOwnProperty

        **bool QJSValue::hasOwnProperty(const QString & name ) const**

        Returns true if this object has an own (not prototype-inherited)
        property of the given **name** , otherwise returns false.

        **See also** **property** () and **hasProperty** ().
        """
        ...

    def hasProperty(self, name: str) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#hasProperty

        **bool QJSValue::hasProperty(const QString & name ) const**

        Returns true if this object has a property of the given **name** ,
        otherwise returns false.

        **See also** **property** () and **hasOwnProperty** ().
        """
        ...

    @typing.overload
    def setProperty(
        self,
        name: str,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#setProperty

        **void QJSValue::setProperty(const QString & name , const QJSValue &
        value )**

        Sets the value of this **QJSValue** 's property with the given **name**
        to the given **value**.

        If this **QJSValue**  is not an object, this function does nothing.

        If this **QJSValue**  does not already have a property with name
        **name** , a new property is created.

        To modify array elements, use the **setProperty** (quint32 arrayIndex,
        const QJSValue &value) overload instead.

        **See also** **property** () and **deleteProperty** ().
        """
        ...

    @typing.overload
    def setProperty(
        self,
        arrayIndex: int,
        value: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#setProperty-1

        **void QJSValue::setProperty(quint32 arrayIndex , const QJSValue & value
        )**

        This is an overloaded function.

        Sets the property at the given **arrayIndex** to the given **value**.

        It is possible to modify elements in an array in two ways. The first is
        to use the array index as the property name:

        jsValueArray.setProperty(QLatin1String("4"), value);

        The second is to use the overload that takes an index:

        jsValueArray.setProperty(4, value);

        Both of these approaches achieve the same result, except that the
        latter:

        * Is easier to use (can use an integer directly)
          * Is faster (no
        conversion to integer)

        If this **QJSValue**  is not an Array object, this function behaves as
        if setProperty() was called with the string representation of
        **arrayIndex**.

        **See also** **property** (quint32 arrayIndex) and **Working With
        Arrays** .
        """
        ...

    @typing.overload
    def property(self, name: str) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#property

        **QJSValue QJSValue::property(const QString & name ) const**

        Returns the value of this **QJSValue** 's property with the given
        **name**. If no such property exists, an undefined **QJSValue**  is
        returned.

        If the property is implemented using a getter function (i.e. has the
        PropertyGetter flag set), calling property() has side-effects on the
        script engine, since the getter function will be called (possibly
        resulting in an uncaught script exception). If an exception occurred,
        property() returns the value that was thrown (typically an `Error`
        object).

        To access array elements, use the **setProperty** (quint32 arrayIndex,
        const QJSValue &value) overload instead.

        **See also** **setProperty** (), **hasProperty** (), and
        **QJSValueIterator** .
        """
        ...

    @typing.overload
    def property(self, arrayIndex: int) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#property-1

        **QJSValue QJSValue::property(quint32 arrayIndex ) const**

        This is an overloaded function.

        Returns the property at the given **arrayIndex**.

        It is possible to access elements in an array in two ways. The first is
        to use the array index as the property name:

        **qDebug** () << jsValueArray.property(QLatin1String("4")).toString();

        The second is to use the overload that takes an index:

        **qDebug** () << jsValueArray.property(4).toString();

        Both of these approaches achieve the same result, except that the
        latter:

        * Is easier to use (can use an integer directly)
          * Is faster (no
        conversion to integer)

        If this **QJSValue**  is not an Array object, this function behaves as
        if property() was called with the string representation of
        **arrayIndex**.
        """
        ...

    def setPrototype(
        self,
        prototype: typing.Union[
            "QJSValue", "QJSValue.SpecialValue", bool, int, float, str
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#setPrototype

        **void QJSValue::setPrototype(const QJSValue & prototype )**

        If this **QJSValue**  is an object, sets the internal prototype
        (`__proto__` property) of this object to be **prototype** ; if the
        **QJSValue**  is null, it sets the prototype to null; otherwise does
        nothing.

        The internal prototype should not be confused with the public property
        with name "prototype"; the public prototype is usually only set on
        functions that act as constructors.

        **See also** **prototype** () and **isObject** ().
        """
        ...

    def prototype(self) -> "QJSValue":
        """
        https://doc.qt.io/qt-6/qjsvalue.html#prototype

        **QJSValue QJSValue::prototype() const**

        If this **QJSValue**  is an object, returns the internal prototype
        (`__proto__` property) of this object; otherwise returns an undefined
        **QJSValue** .

        **See also** **setPrototype** () and **isObject** ().
        """
        ...

    def strictlyEquals(
        self,
        other: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#strictlyEquals

        **bool QJSValue::strictlyEquals(const QJSValue & other ) const**

        Returns true if this **QJSValue**  is equal to **other** using strict
        comparison (no conversion), otherwise returns false. The comparison
        follows the behavior described in **ECMA-262**  section 11.9.6, "The
        Strict Equality Comparison Algorithm".

        If the type of this **QJSValue**  is different from the type of the
        **other** value, this function returns false. If the types are equal,
        the result depends on the type, as shown in the following table:

        TypeResult
        Undefinedtrue
        Nulltrue
        Booleantrue if both values are
        true, false otherwise
        Numberfalse if either value is NaN (Not-a-
        Number); true if values are equal, false otherwise
        Stringtrue if both
        values are exactly the same sequence of characters, false otherwise
        Objecttrue if both values refer to the same object, false otherwise

        **See also** **equals** ().
        """
        ...

    def equals(
        self,
        other: typing.Union["QJSValue", "QJSValue.SpecialValue", bool, int, float, str],
    ) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#equals

        **bool QJSValue::equals(const QJSValue & other ) const**

        Returns true if this **QJSValue**  is equal to **other** , otherwise
        returns false. The comparison follows the behavior described in
        **ECMA-262**  section 11.9.3, "The Abstract Equality Comparison
        Algorithm".

        This function can return true even if the type of this **QJSValue**  is
        different from the type of the **other** value; i.e. the comparison is
        not strict. For example, comparing the number 9 to the string "9"
        returns true; comparing an undefined value to a null value returns true;
        comparing a `Number` object whose primitive value is 6 to a `String`
        object whose primitive value is "6" returns true; and comparing the
        number 1 to the boolean value `true` returns true. If you want to
        perform a comparison without such implicit value conversion, use
        **strictlyEquals** ().

        Note that if this **QJSValue**  or the **other** value are objects,
        calling this function has side effects on the script engine, since the
        engine will call the object's valueOf() function (and possibly
        **toString** ()) in an attempt to convert the object to a primitive
        value (possibly resulting in an uncaught script exception).

        **See also** **strictlyEquals** ().
        """
        ...

    def toDateTime(self) -> QtCore.QDateTime:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toDateTime

        **QDateTime QJSValue::toDateTime() const**

        Returns a **QDateTime**  representation of this value, in local time. If
        this **QJSValue**  is not a date, or the value of the date is NaN (Not-
        a-Number), an invalid **QDateTime**  is returned.

        **See also** **isDate** ().
        """
        ...

    def toQObject(self) -> QtCore.QObject:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toQObject

        **QObject *QJSValue::toQObject() const**

        If this **QJSValue**  is a **QObject** , returns the **QObject**
        pointer that the **QJSValue**  represents; otherwise, returns `nullptr`.

        If the **QObject**  that this **QJSValue**  wraps has been deleted, this
        function returns `nullptr` (i.e. it is possible for toQObject() to
        return `nullptr` even when **isQObject** () returns true).

        **See also** **isQObject** ().
        """
        ...

    def toPrimitive(self) -> QJSPrimitiveValue:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toPrimitive

        **QJSPrimitiveValue QJSValue::toPrimitive() const**

        Converts the value to a **QJSPrimitiveValue** . If the value holds a
        type supported by **QJSPrimitiveValue** , the value is copied. Otherwise
        the value is converted to a string, and the string is stored in
        **QJSPrimitiveValue** .

        **Note:** Conversion of a managed value to a string can throw an
        exception. In particular, symbols cannot be coerced into strings, or a
        custom **toString** () method may throw. In this case the result is the
        undefined value and the engine carries an error after the conversion.
        """
        ...

    @typing.overload
    def toVariant(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toVariant

        **QVariant QJSValue::toVariant(QJSValue::ObjectConversionBehavior
        behavior ) const**

        Returns the **QVariant**  value of this **QJSValue** , if it can be
        converted to a **QVariant** ; otherwise returns an invalid **QVariant**
        . Some JavaScript types and objects have native expressions in Qt. Those
        are converted to their native expressions. For example:

        Input TypeResult
        UndefinedAn invalid **QVariant** .
        NullA
        **QVariant**  containing a null pointer (**QMetaType::Nullptr** ).
        BooleanA **QVariant**  containing the value of the boolean.
        NumberA
        **QVariant**  containing the value of the number.
        StringA **QVariant**
        containing the value of the string.
        **QVariant**  ObjectThe result is
        the **QVariant**  value of the object (no conversion).
        **QObject**
        ObjectA **QVariant**  containing a pointer to the **QObject** .
        Date
        ObjectA **QVariant**  containing the date value (**toDateTime** ()).
        **RegularExpression**  ObjectA **QVariant**  containing the regular
        expression value.

        For other types the **behavior** parameter is relevant. If
        `ConvertJSObjects` is given, a best effort but possibly lossy conversion
        is attempted. Generic JavaScript objects are converted to QVariantMap.
        JavaScript arrays are converted to QVariantList. Each property or
        element is converted to a **QVariant** , recursively; cyclic references
        are not followed. JavaScript function objects are dropped. If
        `RetainJSObjects` is given, the **QJSValue**  is wrapped into a
        **QVariant**  via **QVariant::fromValue** (). The resulting conversion
        is lossless but the internal structure of the objects is not immediately
        accessible.

        **See also** **isVariant** ().
        """
        ...

    @typing.overload
    def toVariant(self, behavior: "QJSValue.ObjectConversionBehavior") -> typing.Any:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toVariant-1

        **QVariant QJSValue::toVariant() const**

        This is an overloaded function.

        Returns toVariant(**ConvertJSObjects** ).

        **See also** **isVariant** ().
        """
        ...

    def toBool(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toBool

        **bool QJSValue::toBool() const**

        Returns the boolean value of this **QJSValue** , using the conversion
        rules described in **ECMA-262**  section 9.2, "ToBoolean".

        Note that if this **QJSValue**  is an object, calling this function has
        side effects on the script engine, since the engine will call the
        object's valueOf() function (and possibly **toString** ()) in an attempt
        to convert the object to a primitive value (possibly resulting in an
        uncaught script exception).

        **See also** **isBool** ().
        """
        ...

    def toUInt(self) -> int:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toUInt

        **quint32 QJSValue::toUInt() const**

        Returns the unsigned 32-bit integer value of this **QJSValue** , using
        the conversion rules described in **ECMA-262**  section 9.6, "ToUint32".

        Note that if this **QJSValue**  is an object, calling this function has
        side effects on the script engine, since the engine will call the
        object's valueOf() function (and possibly **toString** ()) in an attempt
        to convert the object to a primitive value (possibly resulting in an
        uncaught script exception).

        **See also** **toNumber** () and **toInt** ().
        """
        ...

    def toInt(self) -> int:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toInt

        **qint32 QJSValue::toInt() const**

        Returns the signed 32-bit integer value of this **QJSValue** , using the
        conversion rules described in **ECMA-262**  section 9.5, "ToInt32".

        Note that if this **QJSValue**  is an object, calling this function has
        side effects on the script engine, since the engine will call the
        object's valueOf() function (and possibly **toString** ()) in an attempt
        to convert the object to a primitive value (possibly resulting in an
        uncaught script exception).

        **See also** **toNumber** () and **toUInt** ().
        """
        ...

    def toNumber(self) -> float:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toNumber

        **double QJSValue::toNumber() const**

        Returns the number value of this **QJSValue** , as defined in
        **ECMA-262**  section 9.3, "ToNumber".

        Note that if this **QJSValue**  is an object, calling this function has
        side effects on the script engine, since the engine will call the
        object's valueOf() function (and possibly **toString** ()) in an attempt
        to convert the object to a primitive value (possibly resulting in an
        uncaught script exception).

        **See also** **isNumber** (), **toInt** (), and **toUInt** ().
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#toString

        **QString QJSValue::toString() const**

        Returns the string value of this **QJSValue** , as defined in
        **ECMA-262**  section 9.8, "ToString".

        Note that if this **QJSValue**  is an object, calling this function has
        side effects on the script engine, since the engine will call the
        object's toString() function (and possibly valueOf()) in an attempt to
        convert the object to a primitive value (possibly resulting in an
        uncaught script exception).

        **See also** **isString** ().
        """
        ...

    def isUrl(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isUrl

        **bool QJSValue::isUrl() const**

        Returns true if this **QJSValue**  is an object of the URL class;
        otherwise returns false.
        """
        ...

    def isError(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isError

        **bool QJSValue::isError() const**

        Returns true if this **QJSValue**  is an object of the Error class;
        otherwise returns false.

        **See also** **errorType** () and **QJSEngine - Script Exceptions** .
        """
        ...

    def isArray(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isArray

        **bool QJSValue::isArray() const**

        Returns true if this **QJSValue**  is an object of the Array class;
        otherwise returns false.

        **See also** **QJSEngine::newArray** ().
        """
        ...

    def isRegExp(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isRegExp

        **bool QJSValue::isRegExp() const**

        Returns true if this **QJSValue**  is an object of the RegExp class;
        otherwise returns false.
        """
        ...

    def isDate(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isDate

        **bool QJSValue::isDate() const**

        Returns true if this **QJSValue**  is an object of the Date class;
        otherwise returns false.
        """
        ...

    def isObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isObject

        **bool QJSValue::isObject() const**

        Returns true if this **QJSValue**  is of the Object type; otherwise
        returns false.

        Note that function values, variant values, and **QObject**  values are
        objects, so this function returns true for such values.

        **See also** **QJSEngine::newObject** ().
        """
        ...

    def isQObject(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isQObject

        **bool QJSValue::isQObject() const**

        Returns true if this **QJSValue**  is a **QObject** ; otherwise returns
        false.

        Note: This function returns true even if the **QObject**  that this
        **QJSValue**  wraps has been deleted.

        **See also** **toQObject** () and **QJSEngine::newQObject** ().
        """
        ...

    def isVariant(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isVariant

        **bool QJSValue::isVariant() const**

        Returns true if this **QJSValue**  is a variant value; otherwise returns
        false.

        **See also** **toVariant** ().
        """
        ...

    def isUndefined(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isUndefined

        **bool QJSValue::isUndefined() const**

        Returns true if this **QJSValue**  is of the primitive type Undefined or
        if the managed value has been cleared (by deleting the engine).
        Otherwise returns false.
        """
        ...

    def isString(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isString

        **bool QJSValue::isString() const**

        Returns true if this **QJSValue**  is of the primitive type String;
        otherwise returns false.

        **See also** **toString** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isNull

        **bool QJSValue::isNull() const**

        Returns true if this **QJSValue**  is of the primitive type Null;
        otherwise returns false.
        """
        ...

    def isNumber(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isNumber

        **bool QJSValue::isNumber() const**

        Returns true if this **QJSValue**  is of the primitive type Number;
        otherwise returns false.

        **See also** **toNumber** ().
        """
        ...

    def isBool(self) -> bool:
        """
        https://doc.qt.io/qt-6/qjsvalue.html#isBool

        **bool QJSValue::isBool() const**

        Returns true if this **QJSValue**  is of the primitive type Boolean;
        otherwise returns false.

        **See also** **toBool** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from typing import Generic, overload
from PyQt6.sip import *


class array(Generic[T]):
    @overload
    def __getitem__(self, i: int) -> T:
        ...

    @overload
    def __getitem__(self, s: slice) -> array[T]:
        ...

    def __len__(self) -> int:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtSensors import *


class QHumidityReading(QSensorReading):
    """
    https://doc.qt.io/qt-6/qhumidityreading.html

    **Detailed Description**

    **QHumidityReading Units**

    The humidity sensor returns the relative humidity as a percentage, and
    absolute humidity in grams per cubic meter (g/m3). Note that some sensors
    may not support absolute humidity, 0 will be returned in this case.
    """

    def setAbsoluteHumidity(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qhumidityreading.html#setAbsoluteHumidity

        **void QHumidityReading::setAbsoluteHumidity(qreal value )**

        Sets **absoluteHumidity**  to **value**.

        **See also** **absoluteHumidity** ().
        """
        ...

    def absoluteHumidity(self) -> float:
        """
        https://doc.qt.io/qt-6/qhumidityreading.html#absoluteHumidity-prop

        **[read-only] absoluteHumidity : const qreal**

        Absolute humidity Measured in grams per cubic meter. Note that some
        sensors may not support absolute humidity.

        **Access functions:**

        qreal **absoluteHumidity** () const

        **See also** **QHumidityReading Units** .
        """
        ...

    def setRelativeHumidity(self, percent: float) -> None:
        """
        https://doc.qt.io/qt-6/qhumidityreading.html#setRelativeHumidity

        **void QHumidityReading::setRelativeHumidity(qreal humidity )**

        Sets **relativeHumidity**  to **humidity**.

        **See also** **relativeHumidity** ().
        """
        ...

    def relativeHumidity(self) -> float:
        """
        https://doc.qt.io/qt-6/qhumidityreading.html#relativeHumidity-prop

        **[read-only] relativeHumidity : const qreal**

        Relative humidity Returned as a percentage.

        **Access functions:**

        qreal **relativeHumidity** () const

        **See also** **QHumidityReading Units** .

        **Member Function Documentation**
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QWidgetItem(QLayoutItem):
    """
    https://doc.qt.io/qt-6/qwidgetitem.html

    **Detailed Description**

    Normally, you don't need to use this class directly. Qt's built-in layout
    managers provide the following functions for manipulating widgets in
    layouts:

    ClassFunctions
    **QBoxLayout** **addWidget** (), **insertWidget** (),
    **setStretchFactor** ()
    **QGridLayout** **addWidget** ()
    **QStackedLayout** **addWidget** (), **insertWidget** (), **currentWidget**
    (), **setCurrentWidget** (), **widget** ()

    **See also** **QLayout** , **QSpacerItem** , and **QLayoutItem::widget** ().
    """

    def __init__(self, w: QWidget) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#QWidgetItem-1

        **QWidgetItem::QWidgetItem(QWidget * widget )**

        Creates an item containing the given **widget**.
        """
        ...

    def minimumHeightForWidth(self, a0: int) -> int:
        ...

    def controlTypes(self) -> "QSizePolicy.ControlType":
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#controlTypes

        **[override virtual] QSizePolicy::ControlTypes
        QWidgetItem::controlTypes() const**

        Reimplements: **QLayoutItem::controlTypes() const** .

        Returns the control type associated with the widget for which this size
        policy applies.

        **See also** **QSizePolicy::controlType** ().
        """
        ...

    def heightForWidth(self, a0: int) -> int:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#heightForWidth

        **[override virtual] int QWidgetItem::heightForWidth(int w ) const**

        Reimplements: **QLayoutItem::heightForWidth(int) const** .
        """
        ...

    def hasHeightForWidth(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#hasHeightForWidth

        **[override virtual] bool QWidgetItem::hasHeightForWidth() const**

        Reimplements: **QLayoutItem::hasHeightForWidth() const** .
        """
        ...

    def widget(self) -> QWidget:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#widget

        **[override virtual] QWidget *QWidgetItem::widget() const**

        Reimplements: **QLayoutItem::widget() const** .

        Returns the widget managed by this item.
        """
        ...

    def geometry(self) -> QtCore.QRect:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#geometry

        **[override virtual] QRect QWidgetItem::geometry() const**

        Reimplements: **QLayoutItem::geometry() const** .

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, a0: QtCore.QRect) -> None:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#setGeometry

        **[override virtual] void QWidgetItem::setGeometry(const QRect & rect
        )**

        Reimplements: **QLayoutItem::setGeometry** (const QRect &r).

        **See also** **geometry** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#isEmpty

        **[override virtual] bool QWidgetItem::isEmpty() const**

        Reimplements: **QLayoutItem::isEmpty() const** .

        Returns `true` if the widget is hidden; otherwise returns `false`.

        **See also** **QWidget::isHidden** ().
        """
        ...

    def expandingDirections(self) -> QtCore.Qt.Orientation:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#expandingDirections

        **[override virtual] Qt::Orientations QWidgetItem::expandingDirections()
        const**

        Reimplements: **QLayoutItem::expandingDirections() const** .
        """
        ...

    def maximumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#maximumSize

        **[override virtual] QSize QWidgetItem::maximumSize() const**

        Reimplements: **QLayoutItem::maximumSize() const** .
        """
        ...

    def minimumSize(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#minimumSize

        **[override virtual] QSize QWidgetItem::minimumSize() const**

        Reimplements: **QLayoutItem::minimumSize() const** .
        """
        ...

    def sizeHint(self) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qwidgetitem.html#sizeHint

        **[override virtual] QSize QWidgetItem::sizeHint() const**

        Reimplements: **QLayoutItem::sizeHint() const** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QLine(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qline.html

    **Detailed Description**

    A QLine describes a finite length line (or a line segment) on a two-
    dimensional surface. The start and end points of the line are specified
    using integer point accuracy for coordinates. Use the **QLineF**
    constructor to retrieve a floating point copy.

    ![](images/qline-point.png)![](images/qline-coordinates.png)

    The positions of the line's start and end points can be retrieved using the
    **p1** (), **x1** (), **y1** (), **p2** (), **x2** (), and **y2** ()
    functions. The **dx** () and **dy** () functions return the horizontal and
    vertical components of the line. Use **isNull** () to determine whether the
    QLine represents a valid line or a null line.

    Finally, the line can be translated a given offset using the **translate**
    () function.

    **See also** **QLineF** , **QPolygon** , and **QRect** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qline.html#QLine

        **QLine::QLine()**

        Constructs a null line.
        """
        ...

    @typing.overload
    def __init__(self, pt1_: "QPoint", pt2_: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#QLine-1

        **QLine::QLine(const QPoint & p1 , const QPoint & p2 )**

        Constructs a line object that represents the line between **p1** and
        **p2**.
        """
        ...

    @typing.overload
    def __init__(self, x1pos: int, y1pos: int, x2pos: int, y2pos: int) -> None:
        """
        https://doc.qt.io/qt-6/qline.html#QLine-2

        **QLine::QLine(int x1 , int y1 , int x2 , int y2 )**

        Constructs a line object that represents the line between ( **x1** ,
        **y1** ) and ( **x2** , **y2** ).
        """
        ...

    @typing.overload
    def __init__(self, a0: "QLine") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#QLine

        **QLine::QLine()**

        Constructs a null line.
        """
        ...

    def center(self) -> "QPoint":
        """
        https://doc.qt.io/qt-6/qline.html#center

        **[since 5.8] QPoint QLine::center() const**

        Returns the center point of this line. This is equivalent to (**p1** ()
        + **p2** ()) / 2, except it will never overflow.

        This function was introduced in Qt 5.8.
        """
        ...

    def setLine(self, aX1: int, aY1: int, aX2: int, aY2: int) -> None:
        """
        https://doc.qt.io/qt-6/qline.html#setLine

        **void QLine::setLine(int x1 , int y1 , int x2 , int y2 )**

        Sets this line to the start in **x1** , **y1** and end in **x2** ,
        **y2**.

        **See also** **setP1** (), **setP2** (), **p1** (), and **p2** ().
        """
        ...

    def setPoints(self, aP1: "QPoint", aP2: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#setPoints

        **void QLine::setPoints(const QPoint & p1 , const QPoint & p2 )**

        Sets the start point of this line to **p1** and the end point of this
        line to **p2**.

        **See also** **setP1** (), **setP2** (), **p1** (), and **p2** ().
        """
        ...

    def setP2(self, aP2: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#setP2

        **void QLine::setP2(const QPoint & p2 )**

        Sets the end point of this line to **p2**.

        **See also** **setP1** () and **p2** ().
        """
        ...

    def setP1(self, aP1: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#setP1

        **void QLine::setP1(const QPoint & p1 )**

        Sets the starting point of this line to **p1**.

        **See also** **setP2** () and **p1** ().
        """
        ...

    @typing.overload
    def translated(self, p: "QPoint") -> "QLine":
        """
        https://doc.qt.io/qt-6/qline.html#translated

        **QLine QLine::translated(const QPoint & offset ) const**

        Returns this line translated by the given **offset**.
        """
        ...

    @typing.overload
    def translated(self, adx: int, ady: int) -> "QLine":
        """
        https://doc.qt.io/qt-6/qline.html#translated-1

        **QLine QLine::translated(int dx , int dy ) const**

        This is an overloaded function.

        Returns this line translated the distance specified by **dx** and
        **dy**.
        """
        ...

    @typing.overload
    def translate(self, point: "QPoint") -> None:
        """
        https://doc.qt.io/qt-6/qline.html#translate

        **void QLine::translate(const QPoint & offset )**

        Translates this line by the given **offset**.
        """
        ...

    @typing.overload
    def translate(self, adx: int, ady: int) -> None:
        """
        https://doc.qt.io/qt-6/qline.html#translate-1

        **void QLine::translate(int dx , int dy )**

        This is an overloaded function.

        Translates this line the distance specified by **dx** and **dy**.
        """
        ...

    def dy(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#dy

        **int QLine::dy() const**

        Returns the vertical component of the line's vector.

        **See also** **dx** ().
        """
        ...

    def dx(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#dx

        **int QLine::dx() const**

        Returns the horizontal component of the line's vector.

        **See also** **dy** ().
        """
        ...

    def p2(self) -> "QPoint":
        """
        https://doc.qt.io/qt-6/qline.html#p2

        **QPoint QLine::p2() const**

        Returns the line's end point.

        **See also** **setP2** (), **x2** (), **y2** (), and **p1** ().
        """
        ...

    def p1(self) -> "QPoint":
        """
        https://doc.qt.io/qt-6/qline.html#p1

        **QPoint QLine::p1() const**

        Returns the line's start point.

        **See also** **setP1** (), **x1** (), **y1** (), and **p2** ().
        """
        ...

    def y2(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#y2

        **int QLine::y2() const**

        Returns the y-coordinate of the line's end point.

        **See also** **p2** ().
        """
        ...

    def x2(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#x2

        **int QLine::x2() const**

        Returns the x-coordinate of the line's end point.

        **See also** **p2** ().
        """
        ...

    def y1(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#y1

        **int QLine::y1() const**

        Returns the y-coordinate of the line's start point.

        **See also** **p1** ().
        """
        ...

    def x1(self) -> int:
        """
        https://doc.qt.io/qt-6/qline.html#x1

        **int QLine::x1() const**

        Returns the x-coordinate of the line's start point.

        **See also** **p1** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qline.html#isNull

        **bool QLine::isNull() const**

        Returns `true` if the line does not have distinct start and end points;
        otherwise returns `false`.
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtMultimedia import *


class QAudioInput(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qaudioinput.html

    **Detailed Description**

    This class represents an input channel that can be used together with
    **QMediaCaptureSession** . It enables the selection of the physical input
    device to be used, muting the channel, and changing the channel's volume.
    """

    @typing.overload
    def __init__(
        self, deviceInfo: QAudioDevice, parent: typing.Optional[QtCore.QObject] = ...
    ) -> None:
        ...

    @typing.overload
    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        ...

    def setVolume(self, volume: float) -> None:
        ...

    def setMuted(self, muted: bool) -> None:
        """
        https://doc.qt.io/qt-6/qaudioinput.html#muted-prop

        **muted : bool**

        This property holds the muted state of the current media.

        The value will be `true` if the input is muted; otherwise `false`.

        **Access functions:**

        bool **isMuted** () const
        void **setMuted** (bool **muted** )

        **Notifier signal:**

        void **mutedChanged** (bool **muted** )
        """
        ...

    def setDevice(self, device: QAudioDevice) -> None:
        """
        https://doc.qt.io/qt-6/qaudioinput.html#device-prop

        **device : QAudioDevice**

        This property holds the audio device connected to this input.

        The device property represents the audio device connected to this input.
        This property can be used to select an input device from the
        **QMediaDevices::audioInputs** () list.

        You can select the system default audio input by setting this property
        to a default constructed **QAudioDevice**  object.

        **Access functions:**

        QAudioDevice **device** () const
        void **setDevice** (const
        QAudioDevice & **device** )

        **Notifier signal:**

        void **deviceChanged** ()
        """
        ...

    def isMuted(self) -> bool:
        ...

    def volume(self) -> float:
        ...

    def device(self) -> QAudioDevice:
        """
        https://doc.qt.io/qt-6/qaudioinput.html#device-prop

        **device : QAudioDevice**

        This property holds the audio device connected to this input.

        The device property represents the audio device connected to this input.
        This property can be used to select an input device from the
        **QMediaDevices::audioInputs** () list.

        You can select the system default audio input by setting this property
        to a default constructed **QAudioDevice**  object.

        **Access functions:**

        QAudioDevice **device** () const
        void **setDevice** (const
        QAudioDevice & **device** )

        **Notifier signal:**

        void **deviceChanged** ()
        """
        ...

    @property
    def deviceChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def mutedChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...

    @property
    def volumeChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QUndoGroup(QtCore.QObject):
    """
    https://doc.qt.io/qt-6/qundogroup.html

    **Detailed Description**

    For an overview of the Qt's undo framework, see the **overview** .

    An application often has multiple undo stacks, one for each opened document.
    At the same time, an application usually has one undo action and one redo
    action, which triggers undo or redo in the active document.

    QUndoGroup is a group of **QUndoStack**  objects, one of which may be
    active. It has an **undo** () and **redo** () slot, which calls
    **QUndoStack::undo** () and **QUndoStack::redo** () for the active stack. It
    also has the functions **createUndoAction** () and **createRedoAction** ().
    The actions returned by these functions behave in the same way as those
    returned by **QUndoStack::createUndoAction** () and
    **QUndoStack::createRedoAction** () of the active stack.

    Stacks are added to a group with **addStack** () and removed with
    **removeStack** (). A stack is implicitly added to a group when it is
    created with the group as its parent **QObject** .

    It is the programmer's responsibility to specify which stack is active by
    calling **QUndoStack::setActive** (), usually when the associated document
    window receives focus. The active stack may also be set with
    **setActiveStack** (), and is returned by **activeStack** ().

    When a stack is added to a group using **addStack** (), the group does not
    take ownership of the stack. This means the stack has to be deleted
    separately from the group. When a stack is deleted, it is automatically
    removed from a group. A stack may belong to only one group. Adding it to
    another group will cause it to be removed from the previous group.

    A QUndoGroup is also useful in conjunction with **QUndoView** . If a
    **QUndoView**  is set to watch a group using **QUndoView::setGroup** (), it
    will update itself to display the active stack.
    """

    def __init__(self, parent: typing.Optional[QtCore.QObject] = ...) -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#QUndoGroup

        **QUndoGroup::QUndoGroup(QObject * parent = nullptr)**

        Creates an empty QUndoGroup object with parent **parent**.

        **See also** **addStack** ().
        """
        ...

    def undo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#undo

        **[slot] void QUndoGroup::undo()**

        Calls **QUndoStack::undo** () on the active stack.

        If none of the stacks are active, or if the group is empty, this
        function does nothing.

        **See also** **redo** (), **canUndo** (), and **setActiveStack** ().
        """
        ...

    def setActiveStack(self, stack: "QUndoStack") -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#setActiveStack

        **[slot] void QUndoGroup::setActiveStack(QUndoStack * stack )**

        Sets the active stack of this group to **stack**.

        If the stack is not a member of this group, this function does nothing.

        Synonymous with calling **QUndoStack::setActive** () on **stack**.

        The actions returned by **createUndoAction** () and **createRedoAction**
        () will now behave in the same way as those returned by **stack** 's
        **QUndoStack::createUndoAction** () and **QUndoStack::createRedoAction**
        ().

        **See also** **QUndoStack::setActive** () and **activeStack** ().
        """
        ...

    def redo(self) -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#redo

        **[slot] void QUndoGroup::redo()**

        Calls **QUndoStack::redo** () on the active stack.

        If none of the stacks are active, or if the group is empty, this
        function does nothing.

        **See also** **undo** (), **canRedo** (), and **setActiveStack** ().
        """
        ...

    def isClean(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundogroup.html#isClean

        **bool QUndoGroup::isClean() const**

        Returns the value of the active stack's **QUndoStack::isClean** ().

        If none of the stacks are active, or if the group is empty, this
        function returns `true`.

        **See also** **setActiveStack** ().
        """
        ...

    def redoText(self) -> str:
        """
        https://doc.qt.io/qt-6/qundogroup.html#redoText

        **QString QUndoGroup::redoText() const**

        Returns the value of the active stack's **QUndoStack::redoText** ().

        If none of the stacks are active, or if the group is empty, this
        function returns an empty string.

        **See also** **undoText** () and **setActiveStack** ().
        """
        ...

    def undoText(self) -> str:
        """
        https://doc.qt.io/qt-6/qundogroup.html#undoText

        **QString QUndoGroup::undoText() const**

        Returns the value of the active stack's **QUndoStack::undoText** ().

        If none of the stacks are active, or if the group is empty, this
        function returns an empty string.

        **See also** **redoText** () and **setActiveStack** ().
        """
        ...

    def canRedo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundogroup.html#canRedo

        **bool QUndoGroup::canRedo() const**

        Returns the value of the active stack's **QUndoStack::canRedo** ().

        If none of the stacks are active, or if the group is empty, this
        function returns `false`.

        **See also** **canUndo** () and **setActiveStack** ().
        """
        ...

    def canUndo(self) -> bool:
        """
        https://doc.qt.io/qt-6/qundogroup.html#canUndo

        **bool QUndoGroup::canUndo() const**

        Returns the value of the active stack's **QUndoStack::canUndo** ().

        If none of the stacks are active, or if the group is empty, this
        function returns `false`.

        **See also** **canRedo** () and **setActiveStack** ().
        """
        ...

    def createUndoAction(self, parent: QtCore.QObject, prefix: str = ...) -> QAction:
        """
        https://doc.qt.io/qt-6/qundogroup.html#createUndoAction

        **QAction *QUndoGroup::createUndoAction(QObject * parent , const QString
        & prefix = QString()) const**

        Creates an undo **QAction**  object with parent **parent**.

        Triggering this action will cause a call to **QUndoStack::undo** () on
        the active stack. The text of this action will always be the text of the
        command which will be undone in the next call to **undo** (), prefixed
        by **prefix**. If there is no command available for undo, if the group
        is empty or if none of the stacks are active, this action will be
        disabled.

        If **prefix** is empty, the default template "Undo %1" is used instead
        of prefix. Before Qt 4.8, the prefix "Undo" was used by default.

        **See also** **createRedoAction** (), **canUndo** (), and
        **QUndoCommand::text** ().
        """
        ...

    def createRedoAction(self, parent: QtCore.QObject, prefix: str = ...) -> QAction:
        """
        https://doc.qt.io/qt-6/qundogroup.html#createRedoAction

        **QAction *QUndoGroup::createRedoAction(QObject * parent , const QString
        & prefix = QString()) const**

        Creates an redo **QAction**  object with parent **parent**.

        Triggering this action will cause a call to **QUndoStack::redo** () on
        the active stack. The text of this action will always be the text of the
        command which will be redone in the next call to **redo** (), prefixed
        by **prefix**. If there is no command available for redo, if the group
        is empty or if none of the stacks are active, this action will be
        disabled.

        If **prefix** is empty, the default template "Redo %1" is used instead
        of prefix. Before Qt 4.8, the prefix "Redo" was used by default.

        **See also** **createUndoAction** (), **canRedo** (), and
        **QUndoCommand::text** ().
        """
        ...

    def activeStack(self) -> "QUndoStack":
        """
        https://doc.qt.io/qt-6/qundogroup.html#activeStack

        **QUndoStack *QUndoGroup::activeStack() const**

        Returns the active stack of this group.

        If none of the stacks are active, or if the group is empty, this
        function returns `nullptr`.

        **See also** **setActiveStack** () and **QUndoStack::setActive** ().
        """
        ...

    def stacks(self) -> typing.List["QUndoStack"]:
        """
        https://doc.qt.io/qt-6/qundogroup.html#stacks

        **QList<QUndoStack *> QUndoGroup::stacks() const**

        Returns a list of stacks in this group.

        **See also** **addStack** () and **removeStack** ().
        """
        ...

    def removeStack(self, stack: "QUndoStack") -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#removeStack

        **void QUndoGroup::removeStack(QUndoStack * stack )**

        Removes **stack** from this group. If the stack was the active stack in
        the group, the active stack becomes 0.

        **See also** **addStack** (), **stacks** (), and
        **QUndoStack::~QUndoStack** ().
        """
        ...

    def addStack(self, stack: "QUndoStack") -> None:
        """
        https://doc.qt.io/qt-6/qundogroup.html#addStack

        **void QUndoGroup::addStack(QUndoStack * stack )**

        Adds **stack** to this group. The group does not take ownership of the
        stack. Another way of adding a stack to a group is by specifying the
        group as the stack's parent **QObject**  in **QUndoStack::QUndoStack**
        (). In this case, the stack is deleted when the group is deleted, in the
        usual manner of QObjects.

        **See also** **removeStack** (), **stacks** (), and
        **QUndoStack::QUndoStack** ().
        """
        ...

    @property
    def activeStackChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#activeStackChanged

        **[signal] void QUndoGroup::activeStackChanged(QUndoStack * stack )**

        This signal is emitted whenever the active stack of the group changes.
        This can happen when **setActiveStack** () or **QUndoStack::setActive**
        () is called, or when the active stack is removed form the group.
        **stack** is the new active stack. If no stack is active, **stack** is
        0.

        **See also** **setActiveStack** () and **QUndoStack::setActive** ().
        """
        ...

    @property
    def canRedoChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#canRedoChanged

        **[signal] void QUndoGroup::canRedoChanged(bool canRedo )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::canRedoChanged** () or the active stack changes.

        **canRedo** is the new state, or false if the active stack is 0.

        **See also** **QUndoStack::canRedoChanged** () and **setActiveStack**
        ().
        """
        ...

    @property
    def canUndoChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#canUndoChanged

        **[signal] void QUndoGroup::canUndoChanged(bool canUndo )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::canUndoChanged** () or the active stack changes.

        **canUndo** is the new state, or false if the active stack is 0.

        **See also** **QUndoStack::canUndoChanged** () and **setActiveStack**
        ().
        """
        ...

    @property
    def cleanChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#cleanChanged

        **[signal] void QUndoGroup::cleanChanged(bool clean )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::cleanChanged** () or the active stack changes.

        **clean** is the new state, or true if the active stack is 0.

        **See also** **QUndoStack::cleanChanged** () and **setActiveStack** ().
        """
        ...

    @property
    def indexChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#indexChanged

        **[signal] void QUndoGroup::indexChanged(int idx )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::indexChanged** () or the active stack changes.

        **idx** is the new current index, or 0 if the active stack is 0.

        **See also** **QUndoStack::indexChanged** () and **setActiveStack** ().
        """
        ...

    @property
    def redoTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#redoTextChanged

        **[signal] void QUndoGroup::redoTextChanged(const QString & redoText )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::redoTextChanged** () or the active stack changes.

        **redoText** is the new state, or an empty string if the active stack is
        0.

        **See also** **QUndoStack::redoTextChanged** () and **setActiveStack**
        ().
        """
        ...

    @property
    def undoTextChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qundogroup.html#undoTextChanged

        **[signal] void QUndoGroup::undoTextChanged(const QString & undoText )**

        This signal is emitted whenever the active stack emits
        **QUndoStack::undoTextChanged** () or the active stack changes.

        **undoText** is the new state, or an empty string if the active stack is
        0.

        **See also** **QUndoStack::undoTextChanged** () and **setActiveStack**
        ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6 import QtCore


class QCloseEvent(QtCore.QEvent):
    """
    https://doc.qt.io/qt-6/qcloseevent.html

    **Detailed Description**

    Close events are sent to widgets that the user wants to close, usually by
    choosing "Close" from the window menu, or by clicking the **X** title bar
    button. They are also sent when you call **QWidget::close** () to close a
    widget programmatically.

    Close events contain a flag that indicates whether the receiver wants the
    widget to be closed or not. When a widget accepts the close event, it is
    hidden (and destroyed if it was created with the **Qt::WA_DeleteOnClose**
    flag). If it refuses to accept the close event nothing happens. (Under X11
    it is possible that the window manager will forcibly close the window; but
    at the time of writing we are not aware of any window manager that does
    this.)

    The event handler **QWidget::closeEvent** () receives close events. The
    default implementation of this event handler accepts the close event. If you
    do not want your widget to be hidden, or want some special handling, you
    should reimplement the event handler and **ignore** () the event.

    The **closeEvent() in the Application example**  shows a close event handler
    that asks whether to save a document before closing.

    If you want the widget to be deleted when it is closed, create it with the
    **Qt::WA_DeleteOnClose**  flag. This is very useful for independent top-
    level windows in a multi-window application.

    **QObject** s emits the **destroyed** () signal when they are deleted.

    If the last top-level window is closed, the
    **QGuiApplication::lastWindowClosed** () signal is emitted.

    The **isAccepted** () function returns `true` if the event's receiver has
    agreed to close the widget; call **accept** () to agree to close the widget
    and call **ignore** () if the receiver of this event does not want the
    widget to be closed.

    **See also** **QWidget::close** (), **QWidget::hide** (),
    **QObject::destroyed** (), **QCoreApplication::exec** (),
    **QCoreApplication::quit** (), and **QGuiApplication::lastWindowClosed** ().
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qcloseevent.html#QCloseEvent-2

        **QCloseEvent::QCloseEvent()**

        Constructs a close event object.

        **See also** **accept** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from PyQt6.QtQuick import *


class QSGGeometryNode(QSGBasicGeometryNode):
    """
    https://doc.qt.io/qt-6/qsggeometrynode.html

    **Detailed Description**

    The QSGGeometryNode consists of geometry and material. The geometry defines
    the mesh, the vertices and their structure, to be drawn. The Material
    defines how the shape is filled.

    The following is a code snippet illustrating how to create a red line using
    a QSGGeometryNode:

    **QSGGeometry**  *geometry = new **QSGGeometry** (**QSGGeometry**
    ::defaultAttributes_Point2D(), 2);
        geometry->setDrawingMode(GL_LINES);
    geometry->setLineWidth(3);
        geometry->vertexDataAsPoint2D()[0].set(0, 0);
    geometry->vertexDataAsPoint2D()[1].set(width(), height());
    **QSGFlatColorMaterial**  *material = new **QSGFlatColorMaterial** ;
    material->setColor(**QColor** (255, 0, 0));

        **QSGGeometryNode**
    *node = new **QSGGeometryNode** ;
        node->setGeometry(geometry);
    node->setFlag(**QSGNode** ::OwnsGeometry);
        node->setMaterial(material);
    node->setFlag(**QSGNode** ::OwnsMaterial);

    A geometry node must have both geometry and a normal material before it is
    added to the scene graph. When the geometry and materials are changed after
    the node has been added to the scene graph, the user should also mark them
    as dirty using **QSGNode::markDirty** ().

    The geometry node supports two types of materials, the **opaqueMaterial**
    and the normal material. The **opaqueMaterial**  is used when the
    accumulated scene graph opacity at the time of rendering is 1. The primary
    use case is to special case opaque rendering to avoid an extra operation in
    the fragment shader can have significant performance impact on embedded
    graphics chips. The opaque material is optional.

    **Note:** All classes with QSG prefix should be used solely on the scene
    graph's rendering thread. See **Scene Graph and Rendering**  for more
    information.

    **See also** **QSGGeometry**  and **QSGMaterial** .
    """

    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometrynode.html#QSGGeometryNode

        **QSGGeometryNode::QSGGeometryNode()**

        Creates a new geometry node without geometry and material.
        """
        ...

    def opaqueMaterial(self) -> QSGMaterial:
        """
        https://doc.qt.io/qt-6/qsggeometrynode.html#opaqueMaterial

        **QSGMaterial *QSGGeometryNode::opaqueMaterial() const**

        Returns the opaque material of the **QSGGeometryNode** .

        **See also** **setOpaqueMaterial** ().
        """
        ...

    def setOpaqueMaterial(self, material: QSGMaterial) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometrynode.html#setOpaqueMaterial

        **void QSGGeometryNode::setOpaqueMaterial(QSGMaterial * material )**

        Sets the opaque material of this geometry to **material**.

        The opaque material will be preferred by the renderer over the default
        material, as returned by the **material** () function, if it is not null
        and the geometry item has an inherited opacity of 1.

        The opaqueness refers to scene graph opacity, the material is still
        allowed to set **QSGMaterial::Blending**  to true and draw transparent
        pixels.

        If the material is changed without calling setOpaqueMaterial() again,
        the user must also mark the opaque material as dirty using
        **QSGNode::markDirty** ().

        **See also** **opaqueMaterial** ().
        """
        ...

    def material(self) -> QSGMaterial:
        """
        https://doc.qt.io/qt-6/qsggeometrynode.html#material

        **QSGMaterial *QSGGeometryNode::material() const**

        Returns the material of the **QSGGeometryNode** .

        **See also** **setMaterial** ().
        """
        ...

    def setMaterial(self, material: QSGMaterial) -> None:
        """
        https://doc.qt.io/qt-6/qsggeometrynode.html#setMaterial

        **void QSGGeometryNode::setMaterial(QSGMaterial * material )**

        Sets the material of this geometry node to **material**.

        Geometry nodes must have a material before they can be added to the
        scene graph.

        If the material is changed without calling setMaterial() again, the user
        must also mark the material as dirty using **QSGNode::markDirty** ().

        **See also** **material** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsLayoutItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgraphicslayoutitem.html

    **Detailed Description**

    QGraphicsLayoutItem is an abstract class that defines a set of virtual
    functions describing sizes, size policies, and size hints for any object
    arranged by **QGraphicsLayout** . The API contains functions relevant for
    both the item itself and for the user of the item as most of
    QGraphicsLayoutItem's functions are also part of the subclass' public API.

    In most cases, existing layout-aware classes such as **QGraphicsWidget**
    and **QGraphicsLayout**  already provide the functionality you require.
    However, subclassing these classes will enable you to create both graphical
    elements that work well with layouts (**QGraphicsWidget** ) or custom
    layouts (**QGraphicsLayout** ).

    **Subclassing QGraphicsLayoutItem**

    If you create a subclass of QGraphicsLayoutItem and reimplement its virtual
    functions, you will enable the layout to resize and position your item along
    with other QGraphicsLayoutItems including **QGraphicsWidget**  and
    **QGraphicsLayout** .

    You can start by reimplementing important functions: the protected
    **sizeHint** () function, as well as the public **setGeometry** () function.
    If you want your items to be aware of immediate geometry changes, you can
    also reimplement **updateGeometry** ().

    The geometry, size hint, and size policy affect the item's size and
    position. Calling **setGeometry** () will always resize and reposition the
    item immediately. Normally, this function is called by **QGraphicsLayout**
    after the layout has been activated, but it can also be called by the item's
    user at any time.

    The **sizeHint** () function returns the item' minimum, preferred and
    maximum size hints. You can override these properties by calling
    **setMinimumSize** (), **setPreferredSize** () or **setMaximumSize** (). You
    can also use functions such as **setMinimumWidth** () or
    **setMaximumHeight** () to set only the width or height component if
    desired.

    The **effectiveSizeHint** () function, on the other hand, returns a size
    hint for any given **Qt::SizeHint** , and guarantees that the returned size
    is bound to the minimum and maximum sizes and size hints. You can set the
    item's vertical and horizontal size policy by calling **setSizePolicy** ().
    The **sizePolicy**  property is used by the layout system to describe how
    this item prefers to grow or shrink.

    **Nesting QGraphicsLayoutItems**

    QGraphicsLayoutItems can be nested within other QGraphicsLayoutItems,
    similar to layouts that can contain sublayouts. This is done either by
    passing a QGraphicsLayoutItem pointer to QGraphicsLayoutItem's protected
    constructor, or by calling **setParentLayoutItem** (). The
    **parentLayoutItem** () function returns a pointer to the item's layoutItem
    parent. If the item's parent is `nullptr` or if the parent does not inherit
    from **QGraphicsItem** , the **parentLayoutItem** () function then returns
    `nullptr`. **isLayout** () returns `true` if the QGraphicsLayoutItem
    subclass is itself a layout, or false otherwise.

    Qt uses QGraphicsLayoutItem to provide layout functionality in the
    **Graphics View Framework** , but in the future its use may spread
    throughout Qt itself.

    **See also** **QGraphicsWidget** , **QGraphicsLayout** ,
    **QGraphicsLinearLayout** , and **QGraphicsGridLayout** .
    """

    def __init__(
        self, parent: typing.Optional["QGraphicsLayoutItem"] = ..., isLayout: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#QGraphicsLayoutItem

        **QGraphicsLayoutItem::QGraphicsLayoutItem(QGraphicsLayoutItem * parent
        = nullptr, bool isLayout = false)**

        Constructs the QGraphicsLayoutItem object. **parent** becomes the
        object's parent. If **isLayout** is true the item is a layout, otherwise
        **isLayout** is false.
        """
        ...

    def setOwnedByLayout(self, ownedByLayout: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setOwnedByLayout

        **[protected] void QGraphicsLayoutItem::setOwnedByLayout(bool ownership
        )**

        Sets whether a layout should delete this item in its destructor or not.
        **ownership** must be true to in order for the layout to delete it.

        **See also** **ownedByLayout** ().
        """
        ...

    def setGraphicsItem(self, item: "QGraphicsItem") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setGraphicsItem

        **[protected] void QGraphicsLayoutItem::setGraphicsItem(QGraphicsItem *
        item )**

        If the **QGraphicsLayoutItem**  represents a **QGraphicsItem** , and it
        wants to take advantage of the automatic reparenting capabilities of
        **QGraphicsLayout**  it should set this value. Note that if you delete
        **item** and not delete the layout item, you are responsible of calling
        setGraphicsItem(`nullptr`) in order to avoid having a dangling pointer.

        **See also** **graphicsItem** ().
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#sizeHint

        **[pure virtual protected] QSizeF
        QGraphicsLayoutItem::sizeHint(Qt::SizeHint which , const QSizeF &
        constraint = QSizeF()) const**

        This pure virtual function returns the size hint for **which** of the
        **QGraphicsLayoutItem** , using the width or height of **constraint** to
        constrain the output.

        Reimplement this function in a subclass of **QGraphicsLayoutItem**  to
        provide the necessary size hints for your items.

        **See also** **effectiveSizeHint** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#isEmpty

        **[virtual, since 6.0] bool QGraphicsLayoutItem::isEmpty() const**

        Returns `true` if this item is empty, i.e whether it has no content and
        should not occupy any space.

        The default implementation returns `true` true if the item has been
        hidden, unless its **size policy**  has retainSizeWhenHidden set to
        `true`

        This function was introduced in Qt 6.0.

        **See also** **sizePolicy** ().
        """
        ...

    def ownedByLayout(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#ownedByLayout

        **bool QGraphicsLayoutItem::ownedByLayout() const**

        Returns whether a layout should delete this item in its destructor. If
        its true, then the layout will delete it. If its false, then it is
        assumed that another object has the ownership of it, and the layout
        won't delete this item.

        If the item inherits both **QGraphicsItem**  and **QGraphicsLayoutItem**
        (such as **QGraphicsWidget**  does) the item is really part of two
        ownership hierarchies. This property informs what the layout should do
        with its child items when it is destructed. In the case of
        **QGraphicsWidget** , it is preferred that when the layout is deleted it
        won't delete its children (since they are also part of the graphics item
        hierarchy).

        By default this value is initialized to false in **QGraphicsLayoutItem**
        , but it is overridden by **QGraphicsLayout**  to return true. This is
        because **QGraphicsLayout**  is not normally part of the
        **QGraphicsItem**  hierarchy, so the parent layout should delete it.
        Subclasses might override this default behaviour by calling
        **setOwnedByLayout** (true).

        **See also** **setOwnedByLayout** ().
        """
        ...

    def graphicsItem(self) -> "QGraphicsItem":
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#graphicsItem

        **QGraphicsItem *QGraphicsLayoutItem::graphicsItem() const**

        Returns the **QGraphicsItem**  that this layout item represents. For
        **QGraphicsWidget**  it will return itself. For custom items it can
        return an aggregated value.

        **See also** **setGraphicsItem** ().
        """
        ...

    def maximumHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#maximumHeight

        **qreal QGraphicsLayoutItem::maximumHeight() const**

        Returns the maximum height.

        **See also** **setMaximumHeight** (), **setMaximumSize** (), and
        **maximumSize** ().
        """
        ...

    def maximumWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#maximumWidth

        **qreal QGraphicsLayoutItem::maximumWidth() const**

        Returns the maximum width.

        **See also** **setMaximumWidth** (), **setMaximumSize** (), and
        **maximumSize** ().
        """
        ...

    def preferredHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#preferredHeight

        **qreal QGraphicsLayoutItem::preferredHeight() const**

        Returns the preferred height.

        **See also** **setPreferredHeight** (), **setPreferredSize** (), and
        **preferredSize** ().
        """
        ...

    def preferredWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#preferredWidth

        **qreal QGraphicsLayoutItem::preferredWidth() const**

        Returns the preferred width.

        **See also** **setPreferredWidth** (), **setPreferredSize** (), and
        **preferredSize** ().
        """
        ...

    def minimumHeight(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#minimumHeight

        **qreal QGraphicsLayoutItem::minimumHeight() const**

        Returns the minimum height.

        **See also** **setMinimumHeight** (), **setMinimumSize** (), and
        **minimumSize** ().
        """
        ...

    def minimumWidth(self) -> float:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#minimumWidth

        **qreal QGraphicsLayoutItem::minimumWidth() const**

        Returns the minimum width.

        **See also** **setMinimumWidth** (), **setMinimumSize** (), and
        **minimumSize** ().
        """
        ...

    def isLayout(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#isLayout

        **bool QGraphicsLayoutItem::isLayout() const**

        Returns `true` if this **QGraphicsLayoutItem**  is a layout (e.g., is
        inherited by an object that arranges other **QGraphicsLayoutItem**
        objects); otherwise returns `false`.

        **See also** **QGraphicsLayout** .
        """
        ...

    def setParentLayoutItem(self, parent: "QGraphicsLayoutItem") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setParentLayoutItem

        **void QGraphicsLayoutItem::setParentLayoutItem(QGraphicsLayoutItem *
        parent )**

        Sets the parent of this **QGraphicsLayoutItem**  to **parent**.

        **See also** **parentLayoutItem** ().
        """
        ...

    def parentLayoutItem(self) -> "QGraphicsLayoutItem":
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#parentLayoutItem

        **QGraphicsLayoutItem *QGraphicsLayoutItem::parentLayoutItem() const**

        Returns the parent of this **QGraphicsLayoutItem** , or `nullptr` if
        there is no parent, or if the parent does not inherit from
        **QGraphicsLayoutItem**  (**QGraphicsLayoutItem**  is often used through
        multiple inheritance with **QObject** -derived classes).

        **See also** **setParentLayoutItem** ().
        """
        ...

    def updateGeometry(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#updateGeometry

        **[virtual] void QGraphicsLayoutItem::updateGeometry()**

        This virtual function discards any cached size hint information. You
        should always call this function if you change the return value of the
        **sizeHint** () function. Subclasses must always call the base
        implementation when reimplementing this function.

        **See also** **effectiveSizeHint** ().
        """
        ...

    def effectiveSizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#effectiveSizeHint

        **QSizeF QGraphicsLayoutItem::effectiveSizeHint(Qt::SizeHint which ,
        const QSizeF & constraint = QSizeF()) const**

        Returns the effective size hint for this **QGraphicsLayoutItem** .

        **which** is the size hint in question. **constraint** is an optional
        argument that defines a special constrain when calculating the effective
        size hint. By default, **constraint** is **QSizeF** (-1, -1), which
        means there is no constraint to the size hint.

        If you want to specify the widget's size hint for a given width or
        height, you can provide the fixed dimension in **constraint**. This is
        useful for widgets that can grow only either vertically or horizontally,
        and need to set either their width or their height to a special value.

        For example, a text paragraph item fit into a column width of 200 may
        grow vertically. You can pass **QSizeF** (200, -1) as a constraint to
        get a suitable minimum, preferred and maximum height).

        You can adjust the effective size hint by reimplementing **sizeHint** ()
        in a **QGraphicsLayoutItem**  subclass, or by calling one of the
        following functions: **setMinimumSize** (), **setPreferredSize** , or
        **setMaximumSize** () (or a combination of both).

        This function caches each of the size hints and guarantees that
        **sizeHint** () will be called only once for each value of **which** \\-
        unless **constraint** is not specified and **updateGeometry** () has
        been called.

        **See also** **sizeHint** ().
        """
        ...

    def contentsRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#contentsRect

        **QRectF QGraphicsLayoutItem::contentsRect() const**

        Returns the contents rect in local coordinates.

        The contents rect defines the subrectangle used by an associated layout
        when arranging subitems. This function is a convenience function that
        adjusts the item's **geometry** () by its contents margins. Note that
        **getContentsMargins** () is a virtual function that you can reimplement
        to return the item's contents margins.

        **See also** **getContentsMargins** () and **geometry** ().
        """
        ...

    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#getContentsMargins

        **[virtual] void QGraphicsLayoutItem::getContentsMargins(qreal * left ,
        qreal * top , qreal * right , qreal * bottom ) const**

        This virtual function provides the **left** , **top** , **right** and
        **bottom** contents margins for this **QGraphicsLayoutItem** . The
        default implementation assumes all contents margins are 0. The
        parameters point to values stored in qreals. If any of the pointers is
        `nullptr`, that value will not be updated.

        **See also** **QGraphicsWidget::setContentsMargins** ().
        """
        ...

    def geometry(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#geometry

        **QRectF QGraphicsLayoutItem::geometry() const**

        Returns the item's geometry (e.g., position and size) as a **QRectF** .
        This function is equivalent to **QRectF** (pos(), size()).

        **See also** **setGeometry** ().
        """
        ...

    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setGeometry

        **[virtual] void QGraphicsLayoutItem::setGeometry(const QRectF & rect
        )**

        This virtual function sets the geometry of the **QGraphicsLayoutItem**
        to **rect** , which is in parent coordinates (e.g., the top-left corner
        of **rect** is equivalent to the item's position in parent coordinates).

        You must reimplement this function in a subclass of
        **QGraphicsLayoutItem**  to receive geometry updates. The layout will
        call this function when it does a rearrangement.

        If **rect** is outside of the bounds of **minimumSize**  and
        **maximumSize** , it will be adjusted to its closest size so that it is
        within the legal bounds.

        **See also** **geometry** ().
        """
        ...

    def setMaximumHeight(self, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMaximumHeight

        **void QGraphicsLayoutItem::setMaximumHeight(qreal height )**

        Sets the maximum height to **height**.

        **See also** **maximumHeight** (), **setMaximumSize** (), and
        **maximumSize** ().
        """
        ...

    def setMaximumWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMaximumWidth

        **void QGraphicsLayoutItem::setMaximumWidth(qreal width )**

        Sets the maximum width to **width**.

        **See also** **maximumWidth** (), **setMaximumSize** (), and
        **maximumSize** ().
        """
        ...

    def maximumSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#maximumSize

        **QSizeF QGraphicsLayoutItem::maximumSize() const**

        Returns the maximum size.

        **See also** **setMaximumSize** (), **minimumSize** (),
        **preferredSize** (), **Qt::MaximumSize** , and **sizeHint** ().
        """
        ...

    @typing.overload
    def setMaximumSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMaximumSize

        **void QGraphicsLayoutItem::setMaximumSize(const QSizeF & size )**

        Sets the maximum size to **size**. This property overrides **sizeHint**
        () for **Qt::MaximumSize**  and ensures that **effectiveSizeHint** ()
        will never return a size larger than **size**. In order to unset the
        maximum size, use an invalid size.

        **See also** **maximumSize** (), **minimumSize** (), **preferredSize**
        (), **Qt::MaximumSize** , and **sizeHint** ().
        """
        ...

    @typing.overload
    def setMaximumSize(self, aw: float, ah: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMaximumSize-1

        **void QGraphicsLayoutItem::setMaximumSize(qreal w , qreal h )**

        This convenience function is equivalent to calling
        setMaximumSize(**QSizeF** ( **w** , **h** )).

        **See also** **maximumSize** (), **setMinimumSize** (),
        **setPreferredSize** (), and **sizeHint** ().
        """
        ...

    def setPreferredHeight(self, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setPreferredHeight

        **void QGraphicsLayoutItem::setPreferredHeight(qreal height )**

        Sets the preferred height to **height**.

        **See also** **preferredHeight** (), **preferredWidth** (),
        **setPreferredSize** (), and **preferredSize** ().
        """
        ...

    def setPreferredWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setPreferredWidth

        **void QGraphicsLayoutItem::setPreferredWidth(qreal width )**

        Sets the preferred width to **width**.

        **See also** **preferredWidth** (), **preferredHeight** (),
        **setPreferredSize** (), and **preferredSize** ().
        """
        ...

    def preferredSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#preferredSize

        **QSizeF QGraphicsLayoutItem::preferredSize() const**

        Returns the preferred size.

        **See also** **setPreferredSize** (), **minimumSize** (),
        **maximumSize** (), **Qt::PreferredSize** , and **sizeHint** ().
        """
        ...

    @typing.overload
    def setPreferredSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setPreferredSize

        **void QGraphicsLayoutItem::setPreferredSize(const QSizeF & size )**

        Sets the preferred size to **size**. This property overrides
        **sizeHint** () for **Qt::PreferredSize**  and provides the default
        value for **effectiveSizeHint** (). In order to unset the preferred
        size, use an invalid size.

        **See also** **preferredSize** (), **minimumSize** (), **maximumSize**
        (), **Qt::PreferredSize** , and **sizeHint** ().
        """
        ...

    @typing.overload
    def setPreferredSize(self, aw: float, ah: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setPreferredSize-1

        **void QGraphicsLayoutItem::setPreferredSize(qreal w , qreal h )**

        This convenience function is equivalent to calling
        setPreferredSize(**QSizeF** ( **w** , **h** )).

        **See also** **preferredSize** (), **setMaximumSize** (),
        **setMinimumSize** (), and **sizeHint** ().
        """
        ...

    def setMinimumHeight(self, height: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMinimumHeight

        **void QGraphicsLayoutItem::setMinimumHeight(qreal height )**

        Sets the minimum height to **height**.

        **See also** **minimumHeight** (), **setMinimumSize** (), and
        **minimumSize** ().
        """
        ...

    def setMinimumWidth(self, width: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMinimumWidth

        **void QGraphicsLayoutItem::setMinimumWidth(qreal width )**

        Sets the minimum width to **width**.

        **See also** **minimumWidth** (), **setMinimumSize** (), and
        **minimumSize** ().
        """
        ...

    def minimumSize(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#minimumSize

        **QSizeF QGraphicsLayoutItem::minimumSize() const**

        Returns the minimum size.

        **See also** **setMinimumSize** (), **preferredSize** (),
        **maximumSize** (), **Qt::MinimumSize** , and **sizeHint** ().
        """
        ...

    @typing.overload
    def setMinimumSize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMinimumSize

        **void QGraphicsLayoutItem::setMinimumSize(const QSizeF & size )**

        Sets the minimum size to **size**. This property overrides **sizeHint**
        () for **Qt::MinimumSize**  and ensures that **effectiveSizeHint** ()
        will never return a size smaller than **size**. In order to unset the
        minimum size, use an invalid size.

        **See also** **minimumSize** (), **maximumSize** (), **preferredSize**
        (), **Qt::MinimumSize** , **sizeHint** (), **setMinimumWidth** (), and
        **setMinimumHeight** ().
        """
        ...

    @typing.overload
    def setMinimumSize(self, aw: float, ah: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setMinimumSize-1

        **void QGraphicsLayoutItem::setMinimumSize(qreal w , qreal h )**

        This convenience function is equivalent to calling
        setMinimumSize(**QSizeF** ( **w** , **h** )).

        **See also** **minimumSize** (), **setMaximumSize** (),
        **setPreferredSize** (), and **sizeHint** ().
        """
        ...

    def sizePolicy(self) -> "QSizePolicy":
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#sizePolicy

        **QSizePolicy QGraphicsLayoutItem::sizePolicy() const**

        Returns the current size policy.

        **See also** **setSizePolicy** () and **QWidget::sizePolicy** ().
        """
        ...

    @typing.overload
    def setSizePolicy(self, policy: "QSizePolicy") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setSizePolicy

        **void QGraphicsLayoutItem::setSizePolicy(const QSizePolicy & policy )**

        Sets the size policy to **policy**. The size policy describes how the
        item should grow horizontally and vertically when arranged in a layout.

        **QGraphicsLayoutItem** 's default size policy is
        (**QSizePolicy::Fixed** , **QSizePolicy::Fixed** ,
        **QSizePolicy::DefaultType** ), but it is common for subclasses to
        change the default. For example, **QGraphicsWidget**  defaults to
        (**QSizePolicy::Preferred** , **QSizePolicy::Preferred** ,
        **QSizePolicy::DefaultType** ).

        **See also** **sizePolicy** () and **QWidget::sizePolicy** ().
        """
        ...

    @typing.overload
    def setSizePolicy(
        self,
        hPolicy: "QSizePolicy.Policy",
        vPolicy: "QSizePolicy.Policy",
        controlType: "QSizePolicy.ControlType" = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicslayoutitem.html#setSizePolicy-1

        **void QGraphicsLayoutItem::setSizePolicy(QSizePolicy::Policy hPolicy ,
        QSizePolicy::Policy vPolicy , QSizePolicy::ControlType controlType =
        QSizePolicy::DefaultType)**

        This is an overloaded function.

        This function is equivalent to calling setSizePolicy(**QSizePolicy** (
        **hPolicy** , **vPolicy** , **controlType** )).

        **See also** **sizePolicy** () and **QWidget::sizePolicy** ().
        """
        ...
